@@ -58,6 +58,7 @@ src_header_files = Split('''
     Dimension.h
     DispatchResult.h
     DocIterator.h
+    Enchant.h
     Encoding.h
     ErrorList.h
     Exporter.h
@@ -244,6 +245,7 @@ src_post_files = Split('''
 
 src_extra_src_files = Split('''
     ASpell.cpp
+    Enchant.cpp
     ISpell.cpp
     main.cpp
     PSpell.cpp
@@ -300,6 +302,7 @@ src_support_header_files = Split('''
     lyxalgo.h
     lyxlib.h
     lyxtime.h
+    numpunct_lyx_char_type.h
     Messages.h
     os.h
     os_win32.h
@@ -920,7 +923,6 @@ src_frontends_qt4_ui_files = Split('''
     PrefColorsUi.ui
     PrefCompletionUi.ui
     PrefConvertersUi.ui
-    PrefDateUi.ui
     PrefDisplayUi.ui
     PrefEditUi.ui
     PrefFileformatsUi.ui
@@ -928,6 +930,7 @@ src_frontends_qt4_ui_files = Split('''
     PrefInputUi.ui
     PrefLanguageUi.ui
     PrefLatexUi.ui
+    PrefOutputUi.ui
     PrefPathsUi.ui
     PrefPlaintextUi.ui
     PrefPrinterUi.ui
@@ -1175,6 +1178,7 @@ po_extra_files = Split('''
     de.po
     en@boldquot.header
     en@quot.header
+    el.po
     en.po
     es.po
     eu.po
@@ -1293,6 +1297,7 @@ lib_templates_files = Split('''
     dinbrief.lyx
     docbook_article.lyx
     elsarticle.lyx
+    es_beamer-conference-ornate-20min.lyx
     fr_beamer-conference-ornate-20min.lyx
     g-brief-de.lyx
     g-brief-en.lyx
@@ -1593,6 +1598,7 @@ lib_images_math_files = Split('''
     diagdown.png
     diagup.png
     diamond.png
+    diamond2.png
     diamondsuit.png
     digamma.png
     div.png
@@ -2116,6 +2122,11 @@ lib_doc_cs_files = Split('''
 ''')
 
 
+lib_doc_da_files = Split('''
+    Intro.lyx
+''')
+
+
 lib_doc_de_files = Split('''
     Customization.lyx
     DummyDocument1.lyx
@@ -2147,11 +2158,10 @@ lib_doc_de_clipart_files = Split('''
 ''')
 
 
-lib_doc_da_files = Split('''
+lib_doc_el_files = Split('''
     Intro.lyx
 ''')
 
-
 lib_doc_es_files = Split('''
     Customization.lyx
     DocumentoPostizo1.lyx
@@ -2268,7 +2278,12 @@ lib_doc_it_clipart_files = Split('''
 
 
 lib_doc_ja_files = Split('''
+    Customization.lyx
+    DummyDocument1.lyx
+    DummyDocument2.lyx
+    EmbeddedObjects.lyx
     Extended.lyx
+    Formula-numbering.lyx
     Intro.lyx
     LaTeXConfig.lyx
     Math.lyx
@@ -2279,10 +2294,12 @@ lib_doc_ja_files = Split('''
 
 
 lib_doc_ja_clipart_files = Split('''
+    ChildDocumentQt4.png
+    ERT.png
+    ExternalMaterialQt4.png
     floatQt4.png
     footnoteQt4.png
     referenceQt4.png
-    ERT.png
     ToolbarEnvBox.png
 ''')
 
@@ -2449,6 +2466,25 @@ lib_examples_de_files = Split('''
 ''')
 
 
+lib_examples_es_files = Split('''
+    beamer-conference-ornate20min.lyx
+    Braille.lyx
+    ejemplo_con_lyx.lyx
+    ejemplo_sin_lyx.lyx
+    ItemizeBullets.lyx
+    linguistics.lyx
+    multicol.lyx
+    splash.lyx
+    tufte-book.lyx
+    tufte-handout.lyx
+''')
+
+
+lib_examples_el_files = Split('''
+    splash.lyx
+''')
+
+
 lib_examples_fa_files = Split('''
     splash.lyx
 ''')
@@ -2472,17 +2508,6 @@ lib_examples_fr_files = Split('''
 ''')
 
 
-lib_examples_es_files = Split('''
-    Braille.lyx
-    ejemplo_con_lyx.lyx
-    ejemplo_sin_lyx.lyx
-    ItemizeBullets.lyx
-    linguistics.lyx
-    multicol.lyx
-    splash.lyx
-''')
-
-
 lib_examples_eu_files = Split('''
     adibide_gordina.lyx
     adibide_lyx-atua.lyx
@@ -2524,7 +2549,11 @@ lib_examples_it_files = Split('''
 
 lib_examples_ja_files = Split('''
     Braille.lyx
+    linguistics.lyx
+    multicol.lyx
     splash.lyx
+    xyfigure.png
+    xypic.lyx
 ''')
 
 
