@@ -15,65 +15,59 @@
 #include "support/docstring.h"
 
 #include <map>
-#include <iosfwd>
 
 
 namespace lyx {
 
-
 class Author {
 public:
+	///
 	Author() {}
-
+	///
 	Author(docstring const & name, docstring const & email)
 		: name_(name), email_(email), used_(true) {}
-
-	docstring const name() const {
-		return name_;
-	}
-
-	docstring const email() const {
-		return email_;
-	}
-
-	void used(bool u) const {
-		used_ = u;
-	}
-
-	bool used() const {
-		return used_;
-	}
-
+	///
+	docstring name() const { return name_; }
+	///
+	docstring email() const { return email_; }
+	///
+	void setUsed(bool u) const { used_ = u; }
+	///
+	bool used() const { return used_; }
+	///
 	friend std::istream & operator>>(std::istream & os, Author & a);
 
 private:
+	/// The author's name
 	docstring name_;
-
+	/// The author's email address
 	docstring email_;
-
+	///
 	mutable bool used_;
 };
 
 
 class AuthorList {
 public:
+	///
 	AuthorList();
-
+	///
 	int record(Author const & a);
-
+	///
 	void record(int id, Author const & a);
-
+	///
 	Author const & get(int id) const;
-
+	///
 	typedef std::map<int, Author> Authors;
-
+	///
 	Authors::const_iterator begin() const;
-
+	///
 	Authors::const_iterator end() const;
-
+	///
 private:
+	///
 	int last_id_;
-
+	///
 	Authors authors_;
 };
 
