@@ -817,7 +817,7 @@ Buffer::ReadStatus Buffer::readFile(Lexer & lex, FileName const & filename,
 			<< ' ' << quoteName(lyx2lyx.toFilesystemEncoding())
 			<< " -t " << convert<string>(LYX_FORMAT)
 			<< " -o " << quoteName(tmpfile.toFilesystemEncoding())
-			<< ' ' << quoteName(filename.toFilesystemEncoding());
+			<< ' ' << quoteName(filename.toSafeFilesystemEncoding());
 		string const command_str = command.str();
 
 		LYXERR(Debug::INFO, "Running '" << command_str << '\'');
@@ -853,11 +853,20 @@ Buffer::ReadStatus Buffer::readFile(Lexer & lex, FileName const & filename,
 // Should probably be moved to somewhere else: BufferView? LyXView?
 bool Buffer::save() const
 {
+	// ask if the disk file has been externally modified (use checksum method)
+	if (fileName().exists() && isExternallyModified(checksum_method)) {
+		docstring const file = makeDisplayPath(absFileName(), 20);
+		docstring text = bformat(_("Document %1$s has been externally modified. Are you sure "
+							     "you want to overwrite this file?"), file);
+		int const ret = Alert::prompt(_("Overwrite modified file?"),
+			text, 1, 1, _("&Overwrite"), _("&Cancel"));
+		if (ret == 1)
+			return false;
+	}
+
 	// We don't need autosaves in the immediate future. (Asger)
 	resetAutosaveTimers();
 
-	string const encodedFilename = d->filename.toFilesystemEncoding();
-
 	FileName backupName;
 	bool madeBackup = false;
 
@@ -870,7 +879,7 @@ bool Buffer::save() const
 			backupName = FileName(addName(lyxrc.backupdir_path,
 						      mangledName));
 		}
-		if (fileName().copyTo(backupName)) {
+		if (fileName().moveTo(backupName)) {
 			madeBackup = true;
 		} else {
 			Alert::error(_("Backup failure"),
@@ -881,17 +890,6 @@ bool Buffer::save() const
 		}
 	}
 
-	// ask if the disk file has been externally modified (use checksum method)
-	if (fileName().exists() && isExternallyModified(checksum_method)) {
-		docstring const file = makeDisplayPath(absFileName(), 20);
-		docstring text = bformat(_("Document %1$s has been externally modified. Are you sure "
-							     "you want to overwrite this file?"), file);
-		int const ret = Alert::prompt(_("Overwrite modified file?"),
-			text, 1, 1, _("&Overwrite"), _("&Cancel"));
-		if (ret == 1)
-			return false;
-	}
-
 	if (writeFile(d->filename)) {
 		markClean();
 		return true;
@@ -915,11 +913,13 @@ bool Buffer::writeFile(FileName const & fname) const
 		makeDisplayPath(fname.absFilename()));
 	message(str);
 
+	string const encoded_fname = fname.toSafeFilesystemEncoding(os::CREATE);
+
 	if (params().compressed) {
-		gz::ogzstream ofs(fname.toFilesystemEncoding().c_str(), ios::out|ios::trunc);
+		gz::ogzstream ofs(encoded_fname.c_str(), ios::out|ios::trunc);
 		retval = ofs && write(ofs);
 	} else {
-		ofstream ofs(fname.toFilesystemEncoding().c_str(), ios::out|ios::trunc);
+		ofstream ofs(encoded_fname.c_str(), ios::out|ios::trunc);
 		retval = ofs && write(ofs);
 	}
 
@@ -928,7 +928,7 @@ bool Buffer::writeFile(FileName const & fname) const
 		return false;
 	}
 
-	removeAutosaveFile();
+	// removeAutosaveFile();
 
 	saveCheckSum(d->filename);
 	message(str + _(" done."));
@@ -1184,13 +1184,40 @@ void Buffer::writeLaTeXSource(odocstream & os,
 			// FIXME UNICODE
 			// We don't know the encoding of inputpath
 			docstring const inputpath = from_utf8(latex_path(original_path));
-			os << "\\makeatletter\n"
-			   << "\\def\\input@path{{"
-			   << inputpath << "/}}\n"
-			   << "\\makeatother\n";
-			d->texrow.newline();
-			d->texrow.newline();
-			d->texrow.newline();
+			docstring uncodable_glyphs;
+			Encoding const * const enc = runparams.encoding;
+			if (enc) {
+				for (size_t n = 0; n < inputpath.size(); ++n) {
+					docstring const glyph =
+						docstring(1, inputpath[n]);
+					if (enc->latexChar(inputpath[n], true) != glyph) {
+						LYXERR0("Uncodable character '"
+							<< glyph
+							<< "' in input path!");
+						uncodable_glyphs += glyph;
+					}
+				}
+			}
+
+			// warn user if we found uncodable glyphs.
+			if (!uncodable_glyphs.empty()) {
+				frontend::Alert::warning(_("Uncodable character in path"),
+						support::bformat(_("The path of your document\n"
+						  "(%1$s)\n"
+						  "contains glyphs that are unknown in the\n"
+						  "current document encoding (namely %2$s).\n"
+						  "This will likely result in incomplete output.\n\n"
+						  "Chose an appropriate document encoding (such as utf8)\n"
+						  "or change the path name."), inputpath, uncodable_glyphs));
+			} else {
+				os << "\\makeatletter\n"
+				   << "\\def\\input@path{{"
+				   << inputpath << "/}}\n"
+				   << "\\makeatother\n";
+				d->texrow.newline();
+				d->texrow.newline();
+				d->texrow.newline();
+			}
 		}
 
 		// get parent macros (if this buffer has a parent) which will be
@@ -1213,8 +1240,11 @@ void Buffer::writeLaTeXSource(odocstream & os,
 		// output the parent macros
 		MacroSet::iterator it = parentMacros.begin();
 		MacroSet::iterator end = parentMacros.end();
-		for (; it != end; ++it)
-			(*it)->write(os, true);
+		for (; it != end; ++it) {
+			int num_lines = (*it)->write(os, true);
+			d->texrow.newlines(num_lines);
+		}
+		
 	} // output_preamble
 
 	d->texrow.start(paragraphs().begin()->id(), 0);
@@ -1816,12 +1846,17 @@ std::vector<Buffer *> Buffer::getChildren() const
 	Impl::BufferPositionMap::iterator end = d->children_positions.end();
 	for (; it != end; ++it) {
 		Buffer * child = const_cast<Buffer *>(it->first);
-		clist.push_back(child);
+		// ignore recursive includes
+		if (child != this)
+			clist.push_back(child);
 		// there might be grandchildren
 		std::vector<Buffer *> glist = child->getChildren();
 		for (vector<Buffer *>::const_iterator git = glist.begin();
-		     git != glist.end(); ++git)
-			clist.push_back(*git);
+		     git != glist.end(); ++git) {
+			// ignore recursive includes
+			if (*git != this)
+				clist.push_back(*git);
+		}
 	}
 	return clist;
 }
@@ -2472,8 +2507,10 @@ void Buffer::removeAutosaveFile() const
 void Buffer::moveAutosaveFile(support::FileName const & oldauto) const
 {
 	FileName const newauto = getAutosaveFilename();
-	if (!(oldauto == newauto || oldauto.moveTo(newauto)))
-		LYXERR0("Unable to remove autosave file `" << oldauto << "'!");
+	oldauto.refresh();
+	if (newauto != oldauto && oldauto.exists())
+		if (!oldauto.moveTo(newauto))
+			LYXERR0("Unable to remove autosave file `" << oldauto << "'!");
 }
 
 
@@ -2602,7 +2639,9 @@ bool Buffer::doExport(string const & format, bool put_in_tempdir,
 	vector<ExportedFile> const files =
 		runparams.exportdata->externalFiles(format);
 	string const dest = onlyPath(result_file);
-	CopyStatus status = SUCCESS;
+	bool use_force = use_gui ? lyxrc.export_overwrite == ALL_FILES
+				 : force_overwrite == ALL_FILES;
+	CopyStatus status = use_force ? FORCE : SUCCESS;
 	for (vector<ExportedFile>::const_iterator it = files.begin();
 		it != files.end() && status != CANCEL; ++it) {
 		string const fmt = formats.getFormatFromFile(it->sourceName);
@@ -2614,6 +2653,10 @@ bool Buffer::doExport(string const & format, bool put_in_tempdir,
 		message(_("Document export cancelled."));
 	} else if (tmp_result_file.exists()) {
 		// Finally copy the main file
+		use_force = use_gui ? lyxrc.export_overwrite != NO_FILES
+				    : force_overwrite != NO_FILES;
+		if (status == SUCCESS && use_force)
+			status = FORCE;
 		status = copyFile(format, tmp_result_file,
 			FileName(result_file), result_file,
 			status == FORCE);
@@ -2723,7 +2766,7 @@ bool Buffer::readFileHelper(FileName const & s)
 			else
 				str = _("Document was NOT successfully recovered.");
 			str += "\n\n" + bformat(_("Remove emergency file now?\n(%1$s)"),
-						from_utf8(e.absFilename()));
+						makeDisplayPath(e.absFilename()));
 
 			if (!Alert::prompt(_("Delete emergency file?"), str, 1, 1,
 					_("&Remove"), _("&Keep it"))) {
