@@ -146,15 +146,24 @@ public:
 
 	/// set cursor to the given inset. Return true if found.
 	bool setCursorFromInset(Inset const *);
-
+	/// Recenters the BufferView such that the passed cursor
+	/// is in the center.
+	void recenter();
 	/// Ensure that the BufferView cursor is visible.
 	/// This method will automatically scroll and update the BufferView
 	/// if needed.
-	void showCursor();
+	void showCursor(); 
 	/// Ensure the passed cursor \p dit is visible.
 	/// This method will automatically scroll and update the BufferView
 	/// if needed.
-	void showCursor(DocIterator const & dit);
+	/// \param recenter Whether the cursor should be centered on screen
+	void showCursor(DocIterator const & dit, bool recenter = false);
+	/// Scroll to the cursor.
+	void scrollToCursor();
+	/// Scroll to the cursor.
+	/// \param recenter Whether the cursor should be centered on screen
+	/// \return Whether the view was scrolled
+	bool scrollToCursor(DocIterator const & dit, bool recenter);
 	/// LFUN_SCROLL Helper.
 	void lfunScroll(FuncRequest const & cmd);
 	/// scroll down document by the given number of pixels.
@@ -253,6 +262,10 @@ public:
 	Point getPos(DocIterator const & dit, bool boundary) const;
 	/// is the paragraph of the cursor visible ?
 	bool paragraphVisible(DocIterator const & dit) const;
+	/// is the cursor currently visible in the view
+	bool cursorInView(Point const & p, int h) const;
+	/// get the position and height of the cursor
+	void cursorPosAndHeight(Point & p, int & h) const;
 
 
 	///
@@ -289,6 +302,8 @@ public:
 	void insertPlaintextFile(support::FileName const & f, bool asParagraph);
 	///
 	void insertLyXFile(support::FileName const & f);
+	/// save temporary bookmark for jump back navigation
+	void bookmarkEditPosition();
 
 private:
 	/// noncopyable
