@@ -365,7 +365,7 @@ docstring getLaTeXMarkup(docstring const & macro, docstring const & author,
 				ods.put(author[n]);
 				ods << "'>";
 			} else {
-				LYXERR0("Ommitting uncodable character '"
+				LYXERR0("Omitting uncodable character '"
 					<< docstring(1, author[n])
 					<< "' in change author name!");
 				uncodable_author = author;
@@ -380,7 +380,7 @@ docstring getLaTeXMarkup(docstring const & macro, docstring const & author,
 				support::bformat(_("The author name '%1$s',\n"
 				  "used for change tracking, contains glyphs that cannot be\n"
 				  "represented in the current encoding. The respective glyphs\n"
-				  "will be ommitted in the exported LaTeX file.\n\n"
+				  "will be omitted in the exported LaTeX file.\n\n"
 				  "Chose an appropriate document encoding (such as utf8)\n"
 				  "or change the spelling of the author name."), uncodable_author));
 		warned_author = uncodable_author;
@@ -501,14 +501,16 @@ void Changes::addToToc(DocIterator const & cdit, Buffer const & buffer) const
 		Toc::iterator it = change_list.item(0, author);
 		if (it == change_list.end()) {
 			change_list.push_back(TocItem(dit, 0, author));
-			change_list.push_back(TocItem(dit, 1, str));
+			change_list.push_back(TocItem(dit, 1, str,
+				support::wrapParas(str, 4)));
 			continue;
 		}
 		for (++it; it != change_list.end(); ++it) {
 			if (it->depth() == 0 && it->str() != author)
 				break;
 		}
-		change_list.insert(it, TocItem(dit, 1, str));
+		change_list.insert(it, TocItem(dit, 1, str,
+			support::wrapParas(str, 4)));
 	}
 }
 
