@@ -42,10 +42,12 @@
 #include "insets/InsetGraphics.h"
 #include "insets/InsetGraphicsParams.h"
 #include "insets/InsetInclude.h"
+#include "insets/InsetLabel.h"
 #include "insets/InsetTabular.h"
 
 #include "mathed/MathData.h"
 #include "mathed/InsetMath.h"
+#include "mathed/InsetMathHull.h"
 #include "mathed/MathSupport.h"
 
 #include "support/debug.h"
@@ -231,20 +233,49 @@ pasteSelectionHelper(Cursor & cur, ParagraphList const & parlist,
 
 		switch (it->lyxCode()) {
  
+		case MATH_CODE: {
+			// check for equation labels and resolve duplicates
+			InsetMathHull & ins = static_cast<InsetMathHull &>(*it);
+			std::vector<InsetLabel *> labels = ins.getLabels();
+			for (size_t i = 0; i != labels.size(); ++i) {
+				if (!labels[i])
+					continue;
+				InsetLabel * lab = labels[i];
+				docstring const oldname = lab->getParam("name");
+				lab->updateCommand(oldname, false);
+				docstring const newname = lab->getParam("name");
+				if (oldname == newname)
+					continue;
+				// adapt the references
+				for (InsetIterator itt = inset_iterator_begin(in);
+				      itt != i_end; ++itt) {
+					if (itt->lyxCode() == REF_CODE) {
+						InsetCommand & ref =
+							static_cast<InsetCommand &>(*itt);
+						if (ref.getParam("reference") == oldname)
+							ref.setParam("reference", newname);
+					}
+				}
+			}
+			break;
+		}
+		
 		case LABEL_CODE: {
 			// check for duplicates
 			InsetCommand & lab = static_cast<InsetCommand &>(*it);
 			docstring const oldname = lab.getParam("name");
 			lab.updateCommand(oldname, false);
 			docstring const newname = lab.getParam("name");
-			if (oldname != newname) {
-				// adapt the references
-				for (InsetIterator itt = inset_iterator_begin(in); itt != i_end; ++itt) {
-					if (itt->lyxCode() == REF_CODE) {
-						InsetCommand & ref = dynamic_cast<InsetCommand &>(*itt);
-						if (ref.getParam("reference") == oldname)
-							ref.setParam("reference", newname);
-					}
+			if (oldname == newname)
+				break;
+			// adapt the references
+			for (InsetIterator itt = inset_iterator_begin(in);
+			     itt != i_end; ++itt) {
+				if (itt->lyxCode() == REF_CODE) {
+					InsetCommand & ref =
+						static_cast<InsetCommand &>(*itt);
+					if (ref.getParam("reference") == oldname)
+						ref.setParam("reference", newname);
 				}
 			}
 			break;
@@ -262,14 +293,16 @@ pasteSelectionHelper(Cursor & cur, ParagraphList const & parlist,
 			docstring const oldkey = bib.getParam("key");
 			bib.updateCommand(oldkey, false);
 			docstring const newkey = bib.getParam("key");
-			if (oldkey != newkey) {
-				// adapt the references
-				for (InsetIterator itt = inset_iterator_begin(in); itt != i_end; ++itt) {
-					if (itt->lyxCode() == CITE_CODE) {
-						InsetCommand & ref = dynamic_cast<InsetCommand &>(*itt);
-						if (ref.getParam("key") == oldkey)
-							ref.setParam("key", newkey);
-					}
+			if (oldkey == newkey)
+				break;
+			// adapt the references
+			for (InsetIterator itt = inset_iterator_begin(in);
+			     itt != i_end; ++itt) {
+				if (itt->lyxCode() == CITE_CODE) {
+					InsetCommand & ref =
+						static_cast<InsetCommand &>(*itt);
+					if (ref.getParam("key") == oldkey)
+						ref.setParam("key", newkey);
 				}
 			}
 			break;
@@ -445,6 +478,8 @@ void copySelectionHelper(Buffer const & buf, ParagraphList const & pars,
 	// unless the whole selection was deleted
 	if (!isFullyDeleted(copy_pars))
 		acceptChanges(copy_pars, buf.params());
+	else
+		rejectChanges(copy_pars, buf.params());
 
 	DocumentClass * d = const_cast<DocumentClass *>(dc);
 	cutstack.push(make_pair(copy_pars, d));
