@@ -14,11 +14,9 @@
 #include <config.h>
 
 #include "Intl.h"
-#include "debug.h"
 #include "LyXRC.h"
 
-using std::endl;
-
+#include "support/debug.h"
 
 namespace lyx {
 
@@ -39,18 +37,19 @@ void Intl::keyMapOn(bool on)
 			keyMapPrim();
 		else
 			keyMapSec();
-	} else
+	} else {
 		trans.disableKeymap();
+	}
 }
 
 
 void Intl::toggleKeyMap()
 {
-	if (keymapon && (keymap == PRIMARY)) {
+	if (keymapon && (keymap == PRIMARY))
 		keyMapSec();
-	} else if (keymapon) {
+	else if (keymapon)
 		keyMapOn(false);
-	} else
+	else
 		keyMapPrim();
 }
 
@@ -77,7 +76,7 @@ void Intl::keyMapSec()
 
 void Intl::initKeyMapper(bool on)
 {
-	LYXERR(Debug::INIT) << "Initializing key mappings..." << endl;
+	LYXERR(Debug::INIT, "Initializing key mappings...");
 
 	if (trans.setPrimary(prim_lang) == -1)
 		prim_lang.erase();
