@@ -639,6 +639,7 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 			} else if (contains(token, "run BibTeX")) {
 				retval |= UNDEF_CIT;
 			} else if (contains(token, "Rerun LaTeX") ||
+				   contains(token, "Please rerun LaTeX") ||
 				   contains(token, "Rerun to get")) {
 				// at least longtable.sty and bibtopic.sty
 				// might use this.
@@ -744,6 +745,13 @@ int LaTeX::scanLogFile(TeXErrors & terr)
 			} else if (contains(token, "That makes 100 errors")) {
 				// More than 100 errors were reprted
 				retval |= TOO_MANY_ERRORS;
+			} else if (prefixIs(token, "!pdfTeX error:")){
+				// otherwise we dont catch e.g.:
+				// !pdfTeX error: pdflatex (file feyn10): Font feyn10 at 600 not found
+				retval |= ERRORS;
+					terr.insertError(0,
+							 from_local8bit("pdfTeX Error"),
+							 from_local8bit(token));
 			}
 		}
 	}
