@@ -85,6 +85,13 @@ namespace os = support::os;
 
 bool use_gui = true;
 
+
+// Tell what files can be silently overwritten during batch export.
+// Possible values are: NO_FILES, MAIN_FILE, ALL_FILES.
+
+OverwriteFiles force_overwrite = NO_FILES;
+
+
 namespace {
 
 // Filled with the command line arguments "foo" of "-sysdir foo" or
@@ -257,7 +264,7 @@ int LyX::exec(int & argc, char * argv[])
 	easyParse(argc, argv);
 
 	try {
-		init_package(to_utf8(from_local8bit(argv[0])),
+		init_package(os::utf8_argv(0),
 			      cl_system_support, cl_user_support,
 			      top_build_dir_is_one_level_up);
 	} catch (ExceptionMessage const & message) {
@@ -414,7 +421,7 @@ int LyX::init(int & argc, char * argv[])
 		if (argv[argi][0] == '-') {
 			lyxerr << to_utf8(
 				bformat(_("Wrong command line option `%1$s'. Exiting."),
-				from_utf8(argv[argi]))) << endl;
+				from_utf8(os::utf8_argv(argi)))) << endl;
 			return EXIT_FAILURE;
 		}
 	}
@@ -428,7 +435,7 @@ int LyX::init(int & argc, char * argv[])
 
 	// Remaining arguments are assumed to be files to load.
 	for (int argi = argc - 1; argi >= 1; --argi)
-		pimpl_->files_to_load_.push_back(to_utf8(from_local8bit(argv[argi])));
+		pimpl_->files_to_load_.push_back(os::utf8_argv(argi));
 
 	if (first_start) {
 		pimpl_->files_to_load_.push_back(
@@ -971,6 +978,11 @@ int parse_help(string const &, string const &, string &)
 		  "\t-i [--import] fmt file.xxx\n"
 		  "                  where fmt is the import format of choice\n"
 		  "                  and file.xxx is the file to be imported.\n"
+		  "\t-f [--force-overwrite] what\n"
+		  "                  where what is either `all' or `main'.\n"
+		  "                  Using `all', all files are overwritten during\n"
+		  "                  a batch export, otherwise only the main file will be.\n"
+		  "                  Anything else is equivalent to `all', but is not consumed.\n"
 		  "\t-version        summarize version and build info\n"
 			       "Check the LyX man page for more details.")) << endl;
 	exit(0);
@@ -1065,6 +1077,20 @@ int parse_geometry(string const & arg1, string const &, string &)
 }
 
 
+int parse_force(string const & arg, string const &, string &) 
+{
+	if (arg == "all") {
+		force_overwrite = ALL_FILES;
+		return 1;
+	} else if (arg == "main") {
+		force_overwrite = MAIN_FILE;
+		return 1;
+	}
+	force_overwrite = ALL_FILES;
+	return 0;
+}
+
+
 } // namespace anon
 
 
@@ -1086,6 +1112,8 @@ void LyX::easyParse(int & argc, char * argv[])
 	cmdmap["-i"] = parse_import;
 	cmdmap["--import"] = parse_import;
 	cmdmap["-geometry"] = parse_geometry;
+	cmdmap["-f"] = parse_force;
+	cmdmap["--force-overwrite"] = parse_force;
 
 	for (int i = 1; i < argc; ++i) {
 		map<string, cmd_helper>::const_iterator it
@@ -1096,9 +1124,9 @@ void LyX::easyParse(int & argc, char * argv[])
 			continue;
 
 		string const arg =
-			(i + 1 < argc) ? to_utf8(from_local8bit(argv[i + 1])) : string();
+			(i + 1 < argc) ? os::utf8_argv(i + 1) : string();
 		string const arg2 =
-			(i + 2 < argc) ? to_utf8(from_local8bit(argv[i + 2])) : string();
+			(i + 2 < argc) ? os::utf8_argv(i + 2) : string();
 
 		string batch;
 		int const remove = 1 + it->second(arg, arg2, batch);
@@ -1108,6 +1136,7 @@ void LyX::easyParse(int & argc, char * argv[])
 		// Now, remove used arguments by shifting
 		// the following ones remove places down.
 		if (remove > 0) {
+			os::remove_internal_args(i, remove);
 			argc -= remove;
 			for (int j = i; j < argc; ++j)
 				argv[j] = argv[j + remove];
