@@ -152,10 +152,15 @@ public:
 class FontSetChanger : public Changer<MetricsBase> {
 public:
 	///
-	FontSetChanger(MetricsBase & mb, docstring const & font);
-	FontSetChanger(MetricsBase & mb, char const * const font);
+	FontSetChanger(MetricsBase & mb, docstring const & font,
+			bool really_change_font = true);
+	FontSetChanger(MetricsBase & mb, char const * const font,
+			bool really_change_font = true);
 	///
 	~FontSetChanger();
+private:
+	///
+	bool change_;
 };
 
 
@@ -216,12 +221,16 @@ public:
 
 
 // temporarily change the used color
-class ColorChanger : public Changer<FontInfo, std::string> {
+class ColorChanger : public Changer<FontInfo, ColorCode> {
 public:
 	///
-	ColorChanger(FontInfo & font, std::string const & color);
+	ColorChanger(FontInfo & font, docstring const & color,
+		     bool really_change_color = true);
 	///
 	~ColorChanger();
+private:
+	///
+	bool change_;
 };
 
 } // namespace lyx
