@@ -20,11 +20,13 @@ namespace lyx {
 
 OutputParams::OutputParams(Encoding const * enc)
 	: flavor(LATEX), nice(false), moving_arg(false),
-	  local_font(0), encoding(enc), free_spacing(false), use_babel(false),
+	  local_font(0), master_language(0), encoding(enc),
+	  free_spacing(false), use_babel(false),
 	  use_japanese(false), linelen(0), depth(0),
 	  exportdata(new ExportData),
 	  inComment(false), inTableCell(NO), inFloat(NONFLOAT),
-	  inDeletedInset(0), changeOfDeletedInset(Change::UNCHANGED),
+	  inIndexEntry(false), inDeletedInset(0),
+	  changeOfDeletedInset(Change::UNCHANGED),
 	  par_begin(0), par_end(0), isLastPar(false),
 	  dryrun(false), verbatim(false)
 {
