@@ -93,7 +93,7 @@ public:
 	/// Output the surrogate pair formed by \p c and \p next to \p os.
 	/// \return the number of characters written.
 	int latexSurrogatePair(odocstream & os, char_type c, char_type next,
-			       Encoding const &);
+			       OutputParams const &);
 
 	/// Output a space in appropriate formatting (or a surrogate pair
 	/// if the next character is a combining character).
@@ -542,7 +542,7 @@ int Paragraph::eraseChars(pos_type start, pos_type end, bool trackChanges)
 
 
 int Paragraph::Private::latexSurrogatePair(odocstream & os, char_type c,
-		char_type next, Encoding const & encoding)
+		char_type next, OutputParams const & runparams)
 {
 	// Writing next here may circumvent a possible font change between
 	// c and next. Since next is only output if it forms a surrogate pair
@@ -551,12 +551,18 @@ int Paragraph::Private::latexSurrogatePair(odocstream & os, char_type c,
 	// hopefully impossible to input.
 	// FIXME: change tracking
 	// Is this correct WRT change tracking?
+	Encoding const & encoding = *(runparams.encoding);
 	docstring const latex1 = encoding.latexChar(next);
 	docstring const latex2 = encoding.latexChar(c);
 	if (docstring(1, next) == latex1) {
 		// the encoding supports the combination
 		os << latex2 << latex1;
 		return latex1.length() + latex2.length();
+	} else if (runparams.local_font
+		   && runparams.local_font->language()->lang() == "polutonikogreek") {
+		// polutonikogreek only works without the brackets
+		os << latex1 << latex2;
+		return latex1.length() + latex2.length();
 	} else
 		os << latex1 << '{' << latex2 << '}';
 	return latex1.length() + latex2.length() + 2;
@@ -576,9 +582,8 @@ bool Paragraph::Private::simpleTeXBlanks(OutputParams const & runparams,
 	if (i + 1 < int(text_.size())) {
 		char_type next = text_[i + 1];
 		if (Encodings::isCombiningChar(next)) {
-			Encoding const & encoding = *(runparams.encoding);
 			// This space has an accent, so we must always output it.
-			column += latexSurrogatePair(os, ' ', next, encoding) - 1;
+			column += latexSurrogatePair(os, ' ', next, runparams) - 1;
 			return true;
 		}
 	}
@@ -761,7 +766,7 @@ void Paragraph::Private::latexInset(
 
 	if (inset->canTrackChanges()) {
 		column += Changes::latexMarkChange(os, bparams, running_change,
-			Change(Change::UNCHANGED));
+			Change(Change::UNCHANGED), runparams);
 		running_change = Change(Change::UNCHANGED);
 	}
 
@@ -960,7 +965,7 @@ void Paragraph::Private::latexSpecialChar(
 		if (i + 1 < int(text_.size())) {
 			char_type next = text_[i + 1];
 			if (Encodings::isCombiningChar(next)) {
-				column += latexSurrogatePair(os, c, next, encoding) - 1;
+				column += latexSurrogatePair(os, c, next, runparams) - 1;
 				++i;
 				break;
 			}
@@ -2000,7 +2005,8 @@ bool Paragraph::latex(BufferParams const & bparams,
 				running_font = basefont;
 
 				column += Changes::latexMarkChange(os, bparams,
-						runningChange, Change(Change::UNCHANGED));
+						runningChange, Change(Change::UNCHANGED),
+						runparams);
 				runningChange = Change(Change::UNCHANGED);
 
 				os << "}] ";
@@ -2029,7 +2035,8 @@ bool Paragraph::latex(BufferParams const & bparams,
 			basefont = getLayoutFont(bparams, outerfont);
 			running_font = basefont;
 
-			column += Changes::latexMarkChange(os, bparams, runningChange, change);
+			column += Changes::latexMarkChange(os, bparams, runningChange,
+							   change, runparams);
 			runningChange = change;
 		}
 
@@ -2186,7 +2193,8 @@ bool Paragraph::latex(BufferParams const & bparams,
 #endif
 	}
 
-	column += Changes::latexMarkChange(os, bparams, runningChange, Change(Change::UNCHANGED));
+	column += Changes::latexMarkChange(os, bparams, runningChange,
+					   Change(Change::UNCHANGED), runparams);
 
 	// Needed if there is an optional argument but no contents.
 	if (body_pos > 0 && body_pos == size()) {
@@ -2194,8 +2202,11 @@ bool Paragraph::latex(BufferParams const & bparams,
 		return_value = false;
 	}
 
-	if (allowcust && d->endTeXParParams(bparams, os, texrow, runparams))
+	if (allowcust && d->endTeXParParams(bparams, os, texrow, runparams)
+	    && runparams.encoding != prev_encoding) {
 		runparams.encoding = prev_encoding;
+		os << setEncoding(prev_encoding->iconvName());
+	}
 
 	LYXERR(Debug::LATEX, "Paragraph::latex... done " << this);
 	return return_value;
