@@ -6,6 +6,7 @@
  *
  * \author Lars Gullik Bjnnes
  * \author Jean-Marc Lasgouttes
+ * \author Enrico Forestieri
  *
  * Full author contact details are available in file CREDITS.
  */
@@ -15,6 +16,12 @@
 
 #include <boost/signals/trackable.hpp>
 
+#ifdef _WIN32
+#include <windows.h>
+#include <QObject>
+#include <QEvent>
+#endif
+
 
 namespace lyx {
 
@@ -29,7 +36,46 @@ class Server;
  This class encapsulates all the dirty communication and thus provides
  a clean string interface.
  */
+#ifndef _WIN32
 class LyXComm : public boost::signals::trackable {
+#else
+class LyXComm : public QObject {
+	Q_OBJECT
+
+	friend DWORD WINAPI pipeServerWrapper(void *);
+
+public:
+	/// Max number of clients
+	enum { MAX_CLIENTS = 10 };
+
+private:
+	/// Max number of pipe instances
+	enum { MAX_PIPES = 2 * MAX_CLIENTS };
+
+	/// I/O buffer size
+	enum { PIPE_BUFSIZE = 512 };
+
+	/// Pipe client time-out
+	enum { PIPE_TIMEOUT = 5000 };
+
+	/// Pipe states
+	enum PipeState {
+		CONNECTING_STATE,
+		READING_STATE,
+		WRITING_STATE
+	};
+
+	/// Pipe instances
+	typedef struct {
+		OVERLAPPED overlap;
+		HANDLE handle;
+		std::string iobuf;
+		char readbuf[PIPE_BUFSIZE];
+		DWORD nbytes;
+		PipeState state;
+		bool pending_io;
+	} PipeInst;
+#endif
 public:
 	/** When we receive a message, we send it to a client.
 	  This is one of the small things that would have been a lot
@@ -50,7 +96,11 @@ public:
 	void send(std::string const &);
 
 	/// asynch ready-to-be-read notification
+#ifndef _WIN32
 	void read_ready();
+#else
+	void read_ready(DWORD);
+#endif
 
 private:
 	/// the filename of the in pipe
@@ -65,6 +115,7 @@ private:
 	/// Close pipes
 	void closeConnection();
 
+#ifndef _WIN32
 	/// start a pipe
 	int startPipe(std::string const &, bool);
 
@@ -76,6 +127,46 @@ private:
 
 	/// This is -1 if not open
 	int outfd_;
+#else
+	/// The pipe server returns false when exiting due to an error
+	bool pipeServer();
+
+	/// Start an overlapped connection
+	bool startPipe(DWORD);
+
+	/// Reset an overlapped connection
+	bool resetPipe(DWORD, bool close_handle = false);
+
+	/// Close event and pipe handles
+	void closeHandles();
+
+	/// Catch pipe ready-to-be-read notification
+	bool event(QEvent *);
+
+	/// Check whether the pipe server must be stopped
+	bool checkStopServer(DWORD timeout = 0);
+
+	/// The filename of a (in or out) pipe instance
+	std::string const pipeName(DWORD) const;
+
+	/// Pipe instances
+	PipeInst pipe_[MAX_PIPES];
+
+	/// Pipe server control events
+	HANDLE event_[MAX_PIPES + 1];
+
+	/// Reply buffer
+	std::string outbuf_;
+
+	/// Synchronize access to outbuf_
+	HANDLE outbuf_mutex_;
+
+	/// Windows event for stopping the pipe server
+	HANDLE stopserver_;
+
+	/// Pipe server thread handle
+	HANDLE server_thread_;
+#endif
 
 	/// Are we up and running?
 	bool ready_;
@@ -118,7 +209,11 @@ public:
 
 private:
 	/// Names and number of current clients
+#ifndef _WIN32
 	enum { MAX_CLIENTS = 10 };
+#else
+	enum { MAX_CLIENTS = LyXComm::MAX_CLIENTS };
+#endif
 	///
 	std::string clients_[MAX_CLIENTS];
 	///
