@@ -239,11 +239,9 @@ int TextMetrics::rightMargin(pit_type const pit) const
 
 void TextMetrics::applyOuterFont(Font & font) const
 {
-	Font lf(font_);
-	lf.fontInfo().reduce(bv_->buffer().params().getFont().fontInfo());
-	lf.fontInfo().realize(font.fontInfo());
-	lf.setLanguage(font.language());
-	font = lf;
+	FontInfo lf(font_.fontInfo());
+	lf.reduce(bv_->buffer().params().getFont().fontInfo());
+	font.fontInfo().realize(lf); 
 }
 
 
@@ -330,13 +328,14 @@ bool TextMetrics::isRTLBoundary(pit_type pit, pos_type pos) const
 bool TextMetrics::isRTLBoundary(pit_type pit, pos_type pos,
 		Font const & font) const
 {
-	if (!lyxrc.rtl_support)
+	if (!lyxrc.rtl_support
+	    // no RTL boundary at paragraph start
+	    || pos == 0
+	    // if the metrics have not been calculated, then we are not
+	    // on screen and can safely ignore issues about boundaries.
+	    || !contains(pit))
 		return false;
 
-	// no RTL boundary at paragraph start
-	if (pos == 0)
-		return false;
-	
 	ParagraphMetrics & pm = par_metrics_[pit];
 	// no RTL boundary in empty paragraph
 	if (pm.rows().empty())
@@ -1230,10 +1229,18 @@ pos_type TextMetrics::getColumnNearX(pit_type const pit,
 		return 0;
 	}
 
-	// if the first character is a separator, we are in RTL
-	// text. This character will not be painted on screen
+	// This (rtl_support test) is not needed, but gives
+	// some speedup if rtl_support == false
+	bool const lastrow = lyxrc.rtl_support && row.endpos() == par.size();
+
+	// If lastrow is false, we don't need to compute
+	// the value of rtl.
+	bool const rtl = lastrow ? text_->isRTL(buffer, par) : false;
+
+	// if the first character is a separator, and we are in RTL
+	// text, this character will not be painted on screen
 	// and thus we should not count it and skip to the next.
-	if (par.isSeparator(bidi.vis2log(vc)))
+	if (rtl && par.isSeparator(bidi.vis2log(vc)))
 		++vc;
 
 	while (vc < end && tmpx <= x) {
@@ -1261,13 +1268,7 @@ pos_type TextMetrics::getColumnNearX(pit_type const pit,
 	LASSERT(vc <= end, /**/);  // This shouldn't happen.
 
 	boundary = false;
-	// This (rtl_support test) is not needed, but gives
-	// some speedup if rtl_support == false
-	bool const lastrow = lyxrc.rtl_support && row.endpos() == par.size();
 
-	// If lastrow is false, we don't need to compute
-	// the value of rtl.
-	bool const rtl = lastrow ? text_->isRTL(buffer, par) : false;
 	if (lastrow &&
 	    ((rtl  &&  left_side && vc == row.pos() && x < tmpx - 5) ||
 	     (!rtl && !left_side && vc == end  && x > tmpx + 5))) {
