@@ -13,20 +13,15 @@
 #include "BulletsModule.h"
 #include "qt_helpers.h"
 
-#include "support/filetools.h"
-
 #include <QPixmap>
 #include <QPainter>
 
-#include <boost/assert.hpp>
+using namespace std;
 
 namespace lyx {
 
-using support::libFileSearch;
-
-using std::string;
-
-BulletsModule::BulletsModule(QWidget * , char const * , Qt::WFlags)
+BulletsModule::BulletsModule(QWidget * parent)
+    : QWidget(parent)
 {
 	setupUi(this);
 
@@ -58,7 +53,7 @@ BulletsModule::BulletsModule(QWidget * , char const * , Qt::WFlags)
 
 
 void BulletsModule::setupPanel(QListWidget * lw, QString const & panelname,
-	std::string const & fname)
+	string const & fname)
 {
 	connect(lw, SIGNAL(currentItemChanged(QListWidgetItem*, QListWidgetItem*)),
 		this, SLOT(bulletSelected(QListWidgetItem *, QListWidgetItem*)));
@@ -67,7 +62,7 @@ void BulletsModule::setupPanel(QListWidget * lw, QString const & panelname,
 	bulletpaneCO->addItem(panelname);
 
 	// get pixmap with bullets
-	QPixmap pixmap = QPixmap(toqstr(libFileSearch("images", fname, "xpm").absFilename()));
+	QPixmap pixmap(":/images/" + toqstr(fname) + ".png");
 
 	int const w = pixmap.width() / 6;
 	int const h = pixmap.height() / 6;
@@ -192,7 +187,7 @@ void BulletsModule::setBullet(int level, Bullet const & bullet)
 }
 
 
-Bullet const & BulletsModule::getBullet(int level) const
+Bullet const & BulletsModule::bullet(int level) const
 {
 	return bullets_[level];
 }
