@@ -12,7 +12,7 @@
 #ifndef COLORCACHE_H
 #define COLORCACHE_H
 
-#include "ColorCode.h"
+#include "Color.h"
 
 #include <QColor>
 
@@ -29,7 +29,7 @@ public:
 	ColorCache() : initialized_(false) {}
 
 	/// get the given color
-	QColor get(ColorCode color) const;
+	QColor get(Color color) const;
 
 	/// clear all colors
 	void clear() { initialized_ = false; }
