@@ -31,6 +31,7 @@
 #include <QMessageBox>
 #include <QLineEdit>
 #include <QInputDialog>
+#include <QPushButton>
 #include <QSettings>
 
 #include <iomanip>
@@ -141,7 +142,8 @@ namespace Alert {
 
 int prompt(docstring const & title0, docstring const & question,
 		  int default_button, int cancel_button,
-		  docstring const & b1, docstring const & b2, docstring const & b3)
+		  docstring const & b1, docstring const & b2,
+		  docstring const & b3, docstring const & b4)
 {
 	//lyxerr << "PROMPT" << title0 << "FOCUS: " << qApp->focusWidget() << endl;
 	if (!use_gui || lyxerr.debugging()) {
@@ -154,6 +156,7 @@ int prompt(docstring const & title0, docstring const & question,
 		case 0: lyxerr << b1 << endl;
 		case 1: lyxerr << b2 << endl;
 		case 2: lyxerr << b3 << endl;
+		case 3: lyxerr << b4 << endl;
 		}
 		if (!use_gui)
 			return default_button;
@@ -161,20 +164,29 @@ int prompt(docstring const & title0, docstring const & question,
 
 	docstring const title = bformat(_("LyX: %1$s"), title0);
 
-	// For some reason, sometimes Qt uses an hourglass or watch cursor when
+	// For some reason, sometimes Qt uses a hourglass or watch cursor when
 	// displaying the alert. Hence, we ask for the standard cursor shape.
-	// This call has no effect if the cursor has not been overridden.
-	qApp->changeOverrideCursor(Qt::ArrowCursor);
+	qApp->setOverrideCursor(Qt::ArrowCursor);
 
 	// FIXME replace that with guiApp->currentView()
 	//LYXERR0("FOCUS: " << qApp->focusWidget());
-	int res = QMessageBox::information(qApp->focusWidget(),
-					   toqstr(title),
-					   toqstr(formatted(question)),
-					   toqstr(b1),
-					   toqstr(b2),
-					   b3.empty() ? QString::null : toqstr(b3),
-					   default_button, cancel_button);
+	QPushButton * b[4] = { 0, 0, 0, 0 };
+	QMessageBox msg_box(QMessageBox::Information,
+			toqstr(title), toqstr(formatted(question)),
+			QMessageBox::NoButton, qApp->focusWidget());
+	b[0] = msg_box.addButton(b1.empty() ? "OK" : toqstr(b1),
+					QMessageBox::ActionRole);
+	if (!b2.empty())
+		b[1] = msg_box.addButton(toqstr(b2), QMessageBox::ActionRole);
+	if (!b3.empty())
+		b[2] = msg_box.addButton(toqstr(b3), QMessageBox::ActionRole);
+	if (!b4.empty())
+		b[3] = msg_box.addButton(toqstr(b4), QMessageBox::ActionRole);
+	msg_box.setDefaultButton(b[default_button]);
+	msg_box.setEscapeButton(static_cast<QAbstractButton *>(b[cancel_button]));
+	int res = msg_box.exec();
+
+	qApp->restoreOverrideCursor();
 
 	// Qt bug: can return -1 on cancel or WM close, despite the docs.
 	if (res == -1)
@@ -204,12 +216,18 @@ void warning(docstring const & title0, docstring const & message,
 			toqstr(formatted(message)));
 		return;
 	}
+
+	// Don't use a hourglass cursor while displaying the alert
+	qApp->setOverrideCursor(Qt::ArrowCursor);
+
 	if (!askshowagain)
 		QMessageBox::warning(qApp->focusWidget(),
 				toqstr(title),
 				toqstr(formatted(message)));
 	else
 		toggleWarning(title, message);
+
+	qApp->restoreOverrideCursor();
 }
 
 
@@ -232,9 +250,15 @@ void error(docstring const & title0, docstring const & message)
 			toqstr(formatted(message)));
 		return;
 	}
+
+	// Don't use a hourglass cursor while displaying the alert
+	qApp->setOverrideCursor(Qt::ArrowCursor);
+
 	QMessageBox::critical(qApp->focusWidget(),
 			      toqstr(title),
 			      toqstr(formatted(message)));
+
+	qApp->restoreOverrideCursor();
 }
 
 
@@ -249,9 +273,15 @@ void information(docstring const & title0, docstring const & message)
 		return;
 
 	docstring const title = bformat(_("LyX: %1$s"), title0);
+
+	// Don't use a hourglass cursor while displaying the alert
+	qApp->setOverrideCursor(Qt::ArrowCursor);
+
 	QMessageBox::information(qApp->focusWidget(),
 				 toqstr(title),
 				 toqstr(formatted(message)));
+
+	qApp->restoreOverrideCursor();
 }
 
 
