@@ -291,7 +291,7 @@ void GuiGraphics::change_adaptor()
 }
 
 
-void GuiGraphics::change_group(int index)
+void GuiGraphics::change_group(int /*index*/)
 {
 	QString const new_group = groupCO->itemData(
 		groupCO->currentIndex()).toString();
@@ -688,6 +688,8 @@ void GuiGraphics::paramsToDialog(InsetGraphicsParams const & igp)
 
 	// latex section
 	latexoptions->setText(toqstr(igp.special));
+	// cf bug #3852
+	filename->setFocus();
 }
 
 
