@@ -31,6 +31,7 @@
 #include "KeySequence.h"
 #include "Language.h"
 #include "LyXAction.h"
+#include "LyX.h"
 #include "PanelStack.h"
 #include "paper.h"
 #include "Session.h"
@@ -386,21 +387,23 @@ QValidator::State StrftimeValidator::validate(QString & input, int & /*pos*/) co
 
 /////////////////////////////////////////////////////////////////////
 //
-// PrefDate
+// PrefOutput
 //
 /////////////////////////////////////////////////////////////////////
 
-PrefDate::PrefDate(GuiPreferences * form)
-	: PrefModule(qt_(catOutput), qt_("Date format"), form)
+PrefOutput::PrefOutput(GuiPreferences * form)
+	: PrefModule(qt_(catOutput), qt_("General"), form)
 {
 	setupUi(this);
 	DateED->setValidator(new StrftimeValidator(DateED));
 	connect(DateED, SIGNAL(textChanged(QString)),
 		this, SIGNAL(changed()));
+	connect(overwriteCO, SIGNAL(activated(int)),
+		this, SIGNAL(changed()));
 }
 
 
-void PrefDate::on_DateED_textChanged(const QString &)
+void PrefOutput::on_DateED_textChanged(const QString &)
 {
 	QString t = DateED->text();
 	int p = 0;
@@ -410,15 +413,39 @@ void PrefDate::on_DateED_textChanged(const QString &)
 }
 
 
-void PrefDate::apply(LyXRC & rc) const
+void PrefOutput::apply(LyXRC & rc) const
 {
 	rc.date_insert_format = fromqstr(DateED->text());
+
+	switch (overwriteCO->currentIndex()) {
+	case 0:
+		rc.export_overwrite = NO_FILES;
+		break;
+	case 1:
+		rc.export_overwrite = MAIN_FILE;
+		break;
+	case 2:
+		rc.export_overwrite = ALL_FILES;
+		break;
+	}
 }
 
 
-void PrefDate::update(LyXRC const & rc)
+void PrefOutput::update(LyXRC const & rc)
 {
 	DateED->setText(toqstr(rc.date_insert_format));
+
+	switch (rc.export_overwrite) {
+	case NO_FILES:
+		overwriteCO->setCurrentIndex(0);
+		break;
+	case MAIN_FILE:
+		overwriteCO->setCurrentIndex(1);
+		break;
+	case ALL_FILES:
+		overwriteCO->setCurrentIndex(2);
+		break;
+	}
 }
 
 
@@ -1148,6 +1175,9 @@ PrefSpellchecker::PrefSpellchecker(GuiPreferences * form)
 	spellCommandCO->addItem(qt_("ispell"));
 	spellCommandCO->addItem(qt_("aspell"));
 	spellCommandCO->addItem(qt_("hspell"));
+#ifdef USE_ENCHANT
+	spellCommandCO->addItem(qt_("enchant"));
+#else
 #ifdef USE_PSPELL
 	spellCommandCO->addItem(qt_("pspell (library)"));
 #else
@@ -1155,6 +1185,7 @@ PrefSpellchecker::PrefSpellchecker(GuiPreferences * form)
 	spellCommandCO->addItem(qt_("aspell (library)"));
 #endif
 #endif
+#endif
 }
 
 
@@ -1199,7 +1230,7 @@ void PrefSpellchecker::update(LyXRC const & rc)
 	}
 
 	if (rc.use_spell_lib) {
-#if defined(USE_ASPELL) || defined(USE_PSPELL)
+#if defined(USE_ENCHANT) || defined(USE_ASPELL) || defined(USE_PSPELL)
 		spellCommandCO->setCurrentIndex(3);
 #endif
 	}
@@ -2155,8 +2186,6 @@ PrefShortcuts::PrefShortcuts(GuiPreferences * form)
 		this, SLOT(select_bind()));
 	connect(bindFileED, SIGNAL(textChanged(QString)),
 		this, SIGNAL(changed()));
-	connect(removePB, SIGNAL(clicked()),
-		this, SIGNAL(changed()));
 
 	shortcut_ = new GuiShortcutDialog(this);
 	shortcut_bc_.setPolicy(ButtonPolicy::OkCancelPolicy);
@@ -2387,7 +2416,7 @@ void PrefShortcuts::modifyShortcut()
 	QTreeWidgetItem * item = shortcutsTW->currentItem();
 	if (item->flags() & Qt::ItemIsSelectable) {
 		shortcut_->lfunLE->setText(item->text(0));
-		save_lfun_ = item->text(0);
+		save_lfun_ = item->text(0).trimmed();
 		shortcut_->shortcutWG->setText(item->text(1));
 		KeySequence seq;
 		seq.parse(fromqstr(item->data(1, Qt::UserRole).toString()));
@@ -2480,6 +2509,7 @@ void PrefShortcuts::on_newPB_pressed()
 
 void PrefShortcuts::on_removePB_pressed()
 {
+	changed();
 	removeShortcut();
 }
 
@@ -2542,29 +2572,25 @@ void PrefShortcuts::shortcut_okPB_pressed()
 	FuncRequest oldBinding = system_bind_.getBinding(k);
 	if (oldBinding.action == LFUN_UNKNOWN_ACTION)
 		oldBinding = user_bind_.getBinding(k);
-	if (oldBinding == func) {
-		docstring const actionStr = makeCmdString(func);
-		Alert::error(_("Failed to create shortcut"),
-			bformat(_("Shortcut `%1$s' is already bound to:\n%2$s"), 
-			k.print(KeySequence::ForGui), actionStr));
+	if (oldBinding == func)
+		// nothing has changed
 		return;
-	}
 	
 	// make sure this key isn't already bound---and, if so, not unbound
 	FuncCode const unbind = user_unbind_.getBinding(k).action;
-	if (oldBinding.action != LFUN_UNKNOWN_ACTION && unbind == LFUN_UNKNOWN_ACTION)
-	{
+	docstring const action_str = makeCmdString(oldBinding);
+	if (oldBinding.action > LFUN_NOACTION && unbind == LFUN_UNKNOWN_ACTION
+		  && save_lfun_ != toqstr(action_str)) {
 		// FIXME Perhaps we should offer to over-write the old shortcut?
 		// If so, we'll need to remove it from our list, etc.
-		docstring const actionStr = makeCmdString(oldBinding);
 		Alert::error(_("Failed to create shortcut"),
 			bformat(_("Shortcut `%1$s' is already bound to:\n%2$s\n"
 			  "You need to remove that binding before creating a new one."), 
-			k.print(KeySequence::ForGui), actionStr));
+			k.print(KeySequence::ForGui), action_str));
 		return;
 	}
 
-	if (!save_lfun_.isEmpty() && new_lfun == save_lfun_)
+	if (!save_lfun_.isEmpty())
 		// real modification of the lfun's shortcut,
 		// so remove the previous one
 		removeShortcut();
@@ -2669,8 +2695,8 @@ GuiPreferences::GuiPreferences(GuiView & lv)
 	addModule(new PrefSpellchecker(this));
 
 	addModule(new PrefPrinter(this));
-	PrefDate * dateFormat = new PrefDate(this);
-	addModule(dateFormat);
+	PrefOutput * general = new PrefOutput(this);
+	addModule(general);
 	addModule(new PrefPlaintext(this));
 	addModule(new PrefLatex(this));
 
@@ -2695,7 +2721,7 @@ GuiPreferences::GuiPreferences(GuiView & lv)
 	bc().setRestore(restorePB);
 
 	// initialize the strftime validator
-	bc().addCheckedLineEdit(dateFormat->DateED);
+	bc().addCheckedLineEdit(general->DateED);
 }
 
 
