@@ -53,56 +53,96 @@ GuiTabular::GuiTabular(GuiView & lv)
 	bottomspaceED->setValidator(new LengthValidator(bottomspaceED));
 	interlinespaceED->setValidator(new LengthValidator(interlinespaceED));
 
+	widthUnit->setCurrentItem(useMetricUnits() ? Length::CM : Length::IN);
+
 	connect(topspaceED, SIGNAL(returnPressed()),
 		this, SLOT(topspace_changed()));
 	connect(topspaceUnit, SIGNAL(selectionChanged(lyx::Length::UNIT)),
 		this, SLOT(topspace_changed()));
-	connect(topspaceCO, SIGNAL(activated(int)), this, SLOT(topspace_changed()));
+	connect(topspaceCO, SIGNAL(activated(int)),
+		this, SLOT(topspace_changed()));
 	connect(bottomspaceED, SIGNAL(returnPressed()),
 		this, SLOT(bottomspace_changed()));
 	connect(bottomspaceUnit, SIGNAL(selectionChanged(lyx::Length::UNIT)),
 		this, SLOT(bottomspace_changed()));
-	connect(bottomspaceCO, SIGNAL(activated(int)), this, SLOT(bottomspace_changed()));
+	connect(bottomspaceCO, SIGNAL(activated(int)),
+		this, SLOT(bottomspace_changed()));
 	connect(interlinespaceED, SIGNAL(returnPressed()),
 		this, SLOT(interlinespace_changed()));
 	connect(interlinespaceUnit, SIGNAL(selectionChanged(lyx::Length::UNIT)),
 		this, SLOT(interlinespace_changed()));
-	connect(interlinespaceCO, SIGNAL(activated(int)), this, SLOT(interlinespace_changed()));
-	connect(booktabsRB, SIGNAL(clicked(bool)), this, SLOT(booktabsChanged(bool)));
-	connect(borderDefaultRB, SIGNAL(clicked(bool)), this, SLOT(booktabsChanged(bool)));
-	connect(borderSetPB, SIGNAL(clicked()), this, SLOT(borderSet_clicked()));
-	connect(borderUnsetPB, SIGNAL(clicked()), this, SLOT(borderUnset_clicked()));
-	connect(longTabularCB, SIGNAL(toggled(bool)), longtableGB, SLOT(setEnabled(bool)));
-	connect(longTabularCB, SIGNAL(toggled(bool)), newpageCB, SLOT(setEnabled(bool)));
-	connect(hAlignCB, SIGNAL(activated(int)), this, SLOT(hAlign_changed(int)));
-	connect(vAlignCB, SIGNAL(activated(int)), this, SLOT(vAlign_changed(int)));
-	connect(multicolumnCB, SIGNAL(clicked()), this, SLOT(multicolumn_clicked()));
-	connect(newpageCB, SIGNAL(clicked()), this, SLOT(ltNewpage_clicked()));
-	connect(headerStatusCB, SIGNAL(clicked()), this, SLOT(ltHeaderStatus_clicked()));
-	connect(headerBorderAboveCB, SIGNAL(clicked()), this, SLOT(ltHeaderBorderAbove_clicked()));
-	connect(headerBorderBelowCB, SIGNAL(clicked()), this, SLOT(ltHeaderBorderBelow_clicked()));
-	connect(firstheaderStatusCB, SIGNAL(clicked()), this, SLOT(ltFirstHeaderStatus_clicked()));
-	connect(firstheaderBorderAboveCB, SIGNAL(clicked()), this, SLOT(ltFirstHeaderBorderAbove_clicked()));
-	connect(firstheaderBorderBelowCB, SIGNAL(clicked()), this, SLOT(ltFirstHeaderBorderBelow_clicked()));
-	connect(firstheaderNoContentsCB, SIGNAL(clicked()), this, SLOT(ltFirstHeaderEmpty_clicked()));
-	connect(footerStatusCB, SIGNAL(clicked()), this, SLOT(ltFooterStatus_clicked()));
-	connect(footerBorderAboveCB, SIGNAL(clicked()), this, SLOT(ltFooterBorderAbove_clicked()));
-	connect(footerBorderBelowCB, SIGNAL(clicked()), this, SLOT(ltFooterBorderBelow_clicked()));
-	connect(lastfooterStatusCB, SIGNAL(clicked()), this, SLOT(ltLastFooterStatus_clicked()));
-	connect(lastfooterBorderAboveCB, SIGNAL(clicked()), this, SLOT(ltLastFooterBorderAbove_clicked()));
-	connect(lastfooterBorderBelowCB, SIGNAL(clicked()), this, SLOT(ltLastFooterBorderBelow_clicked()));
-	connect(lastfooterNoContentsCB, SIGNAL(clicked()), this, SLOT(ltLastFooterEmpty_clicked()));
-	connect(specialAlignmentED, SIGNAL(returnPressed()), this, SLOT(specialAlignment_changed()));
-	connect(widthED, SIGNAL(editingFinished()), this, SLOT(width_changed()));
-	connect(widthUnit, SIGNAL(selectionChanged(lyx::Length::UNIT)), this, SLOT(width_changed()));
-	connect(closePB, SIGNAL(clicked()), this, SLOT(close_clicked()));
-	connect(borders, SIGNAL(topSet(bool)), this, SLOT(topBorder_changed()));
-	connect(borders, SIGNAL(bottomSet(bool)), this, SLOT(bottomBorder_changed()));
-	connect(borders, SIGNAL(rightSet(bool)), this, SLOT(rightBorder_changed()));
-	connect(borders, SIGNAL(leftSet(bool)), this, SLOT(leftBorder_changed()));
-	connect(rotateTabularCB, SIGNAL(clicked()), this, SLOT(rotateTabular()));
-	connect(rotateCellCB, SIGNAL(clicked()), this, SLOT(rotateCell()));
-	connect(longTabularCB, SIGNAL(clicked()), this, SLOT(longTabular()));
+	connect(interlinespaceCO, SIGNAL(activated(int)),
+		this, SLOT(interlinespace_changed()));
+	connect(booktabsRB, SIGNAL(clicked(bool)),
+		this, SLOT(booktabsChanged(bool)));
+	connect(borderDefaultRB, SIGNAL(clicked(bool)),
+		this, SLOT(booktabsChanged(bool)));
+	connect(borderSetPB, SIGNAL(clicked()),
+		this, SLOT(borderSet_clicked()));
+	connect(borderUnsetPB, SIGNAL(clicked()),
+		this, SLOT(borderUnset_clicked()));
+	connect(longTabularCB, SIGNAL(toggled(bool)),
+		longtableGB, SLOT(setEnabled(bool)));
+	connect(longTabularCB, SIGNAL(toggled(bool)),
+		newpageCB, SLOT(setEnabled(bool)));
+	connect(hAlignCB, SIGNAL(activated(int)),
+		this, SLOT(hAlign_changed(int)));
+	connect(vAlignCB, SIGNAL(activated(int)),
+		this, SLOT(vAlign_changed(int)));
+	connect(multicolumnCB, SIGNAL(clicked()),
+		this, SLOT(multicolumn_clicked()));
+	connect(newpageCB, SIGNAL(clicked()),
+		this, SLOT(ltNewpage_clicked()));
+	connect(headerStatusCB, SIGNAL(clicked()),
+		this, SLOT(ltHeaderStatus_clicked()));
+	connect(headerBorderAboveCB, SIGNAL(clicked()),
+		this, SLOT(ltHeaderBorderAbove_clicked()));
+	connect(headerBorderBelowCB, SIGNAL(clicked()),
+		this, SLOT(ltHeaderBorderBelow_clicked()));
+	connect(firstheaderStatusCB, SIGNAL(clicked()),
+		this, SLOT(ltFirstHeaderStatus_clicked()));
+	connect(firstheaderBorderAboveCB, SIGNAL(clicked()),
+		this, SLOT(ltFirstHeaderBorderAbove_clicked()));
+	connect(firstheaderBorderBelowCB, SIGNAL(clicked()),
+		this, SLOT(ltFirstHeaderBorderBelow_clicked()));
+	connect(firstheaderNoContentsCB, SIGNAL(clicked()),
+		this, SLOT(ltFirstHeaderEmpty_clicked()));
+	connect(footerStatusCB, SIGNAL(clicked()),
+		this, SLOT(ltFooterStatus_clicked()));
+	connect(footerBorderAboveCB, SIGNAL(clicked()),
+		this, SLOT(ltFooterBorderAbove_clicked()));
+	connect(footerBorderBelowCB, SIGNAL(clicked()),
+		this, SLOT(ltFooterBorderBelow_clicked()));
+	connect(lastfooterStatusCB, SIGNAL(clicked()),
+		this, SLOT(ltLastFooterStatus_clicked()));
+	connect(lastfooterBorderAboveCB, SIGNAL(clicked()),
+		this, SLOT(ltLastFooterBorderAbove_clicked()));
+	connect(lastfooterBorderBelowCB, SIGNAL(clicked()),
+		this, SLOT(ltLastFooterBorderBelow_clicked()));
+	connect(lastfooterNoContentsCB, SIGNAL(clicked()),
+		this, SLOT(ltLastFooterEmpty_clicked()));
+	connect(specialAlignmentED, SIGNAL(returnPressed()),
+		this, SLOT(specialAlignment_changed()));
+	connect(widthED, SIGNAL(editingFinished()),
+		this, SLOT(width_changed()));
+	connect(widthUnit, SIGNAL(selectionChanged(lyx::Length::UNIT)),
+		this, SLOT(width_changed()));
+	connect(closePB, SIGNAL(clicked()),
+		this, SLOT(close_clicked()));
+	connect(borders, SIGNAL(topSet(bool)),
+		this, SLOT(topBorder_changed()));
+	connect(borders, SIGNAL(bottomSet(bool)),
+		this, SLOT(bottomBorder_changed()));
+	connect(borders, SIGNAL(rightSet(bool)),
+		this, SLOT(rightBorder_changed()));
+	connect(borders, SIGNAL(leftSet(bool)),
+		this, SLOT(leftBorder_changed()));
+	connect(rotateTabularCB, SIGNAL(clicked()),
+		this, SLOT(rotateTabular()));
+	connect(rotateCellCB, SIGNAL(clicked()),
+		this, SLOT(rotateCell()));
+	connect(longTabularCB, SIGNAL(clicked()),
+		this, SLOT(longTabular()));
 
 	bc().setPolicy(ButtonPolicy::IgnorantPolicy);
 	
@@ -191,7 +231,8 @@ void GuiTabular::topspace_changed()
 		case 2: {
 			if (!topspaceED->text().isEmpty())
 				set(Tabular::SET_TOP_SPACE,
-					widgetsToLength(topspaceED, topspaceUnit));
+				    widgetsToLength(topspaceED,
+					            topspaceUnit));
 			if (!bc().policy().isReadOnly()) {
 				topspaceED->setEnabled(true);
 				topspaceUnit->setEnabled(true);
@@ -221,7 +262,8 @@ void GuiTabular::bottomspace_changed()
 		case 2: {
 			if (!bottomspaceED->text().isEmpty())
 				set(Tabular::SET_BOTTOM_SPACE,
-					widgetsToLength(bottomspaceED, bottomspaceUnit));
+				    widgetsToLength(bottomspaceED,
+					            bottomspaceUnit));
 			if (!bc().policy().isReadOnly()) {
 				bottomspaceED->setEnabled(true);
 				bottomspaceUnit->setEnabled(true);
@@ -251,7 +293,8 @@ void GuiTabular::interlinespace_changed()
 		case 2: {
 			if (!interlinespaceED->text().isEmpty())
 				set(Tabular::SET_INTERLINE_SPACE,
-					widgetsToLength(interlinespaceED, interlinespaceUnit));
+				    widgetsToLength(interlinespaceED,
+					            interlinespaceUnit));
 			if (!bc().policy().isReadOnly()) {
 				interlinespaceED->setEnabled(true);
 				interlinespaceUnit->setEnabled(true);
@@ -408,9 +451,6 @@ void GuiTabular::ltHeaderStatus_clicked()
 		set(Tabular::SET_LTHEAD, "");
 	else
 		set(Tabular::UNSET_LTHEAD, "");
-	headerBorderAboveCB->setEnabled(enable);
-	headerBorderBelowCB->setEnabled(enable);
-	firstheaderNoContentsCB->setEnabled(enable);
 	changed();
 }
 
@@ -462,8 +502,6 @@ void GuiTabular::ltFirstHeaderStatus_clicked()
 		set(Tabular::SET_LTFIRSTHEAD, "");
 	else
 		set(Tabular::UNSET_LTFIRSTHEAD, "");
-	firstheaderBorderAboveCB->setEnabled(enable);
-	firstheaderBorderBelowCB->setEnabled(enable);
 	changed();
 }
 
@@ -475,9 +513,6 @@ void GuiTabular::ltFirstHeaderEmpty_clicked()
 		set(Tabular::SET_LTFIRSTHEAD, "empty");
 	else
 		set(Tabular::UNSET_LTFIRSTHEAD, "empty");
-	firstheaderStatusCB->setEnabled(!enable);
-	firstheaderBorderAboveCB->setEnabled(!enable);
-	firstheaderBorderBelowCB->setEnabled(!enable);
 	changed();
 }
 
@@ -489,9 +524,6 @@ void GuiTabular::ltFooterStatus_clicked()
 		set(Tabular::SET_LTFOOT, "");
 	else
 		set(Tabular::UNSET_LTFOOT, "");
-	footerBorderAboveCB->setEnabled(enable);
-	footerBorderBelowCB->setEnabled(enable);
-	lastfooterNoContentsCB->setEnabled(enable);
 	changed();
 }
 
@@ -523,8 +555,6 @@ void GuiTabular::ltLastFooterStatus_clicked()
 		set(Tabular::SET_LTLASTFOOT, "");
 	else
 		set(Tabular::UNSET_LTLASTFOOT, "");
-	lastfooterBorderAboveCB->setEnabled(enable);
-	lastfooterBorderBelowCB->setEnabled(enable);
 	changed();
 }
 
@@ -556,9 +586,6 @@ void GuiTabular::ltLastFooterEmpty_clicked()
 		set(Tabular::SET_LTLASTFOOT, "empty");
 	else
 		set(Tabular::UNSET_LTLASTFOOT, "empty");
-	lastfooterStatusCB->setEnabled(!enable);
-	lastfooterBorderAboveCB->setEnabled(!enable);
-	lastfooterBorderBelowCB->setEnabled(!enable);
 	changed();
 }
 
@@ -629,10 +656,12 @@ void GuiTabular::updateContents()
 	docstring special;
 
 	if (multicol) {
-		special = getAlignSpecial(tabular_, cell, Tabular::SET_SPECIAL_MULTI);
+		special = getAlignSpecial(tabular_, cell,
+			Tabular::SET_SPECIAL_MULTI);
 		pwidth = getMColumnPWidth(tabular_, cell);
 	} else {
-		special = getAlignSpecial(tabular_, cell, Tabular::SET_SPECIAL_COLUMN);
+		special = getAlignSpecial(tabular_, cell,
+			Tabular::SET_SPECIAL_COLUMN);
 		pwidth = getColumnPWidth(tabular_, cell);
 	}
 
@@ -702,10 +731,10 @@ void GuiTabular::updateContents()
 	interlinespaceCO->setEnabled(!isReadonly);
 
 	string colwidth;
-	if (!pwidth.zero())
+	if (!pwidth.zero()) {
 		colwidth = pwidth.asString();
-	lengthToWidgets(widthED, widthUnit,
-		colwidth, default_unit);
+		lengthToWidgets(widthED, widthUnit, colwidth, default_unit);
+	}
 
 	widthED->setEnabled(!isReadonly);
 	widthUnit->setEnabled(!isReadonly);
@@ -800,7 +829,6 @@ void GuiTabular::updateContents()
 	// a first header makes no sense
 	firstheaderStatusCB->setEnabled(funcEnabled(Tabular::SET_LTFIRSTHEAD)
 		&& !firstheaderNoContentsCB->isChecked());
-	//firstheaderStatusCB->setEnabled(!firstheaderNoContentsCB->isChecked());
 	headerBorderAboveCB->setEnabled(funcEnabled(Tabular::SET_LTHEAD));
 	headerBorderBelowCB->setEnabled(funcEnabled(Tabular::SET_LTHEAD));
 	headerStatusCB->setEnabled(funcEnabled(Tabular::SET_LTHEAD));
@@ -841,6 +869,12 @@ void GuiTabular::updateContents()
 	}
 
 	row_set = tabular_.getRowOfLTFirstHead(row, ltt);
+	// check if setting a first header is allowed
+	// additionally check firstheaderStatusCB because when this is the
+	// case a first header makes no sense
+	firstheaderStatusCB->setEnabled(
+		funcEnabled(Tabular::SET_LTFIRSTHEAD)
+		&& !firstheaderNoContentsCB->isChecked());
 	firstheaderStatusCB->setChecked(row_set);
 	if (ltt.set && (!ltt.empty || !use_empty)) {
 		firstheaderBorderAboveCB->setChecked(ltt.topDL);
@@ -873,6 +907,12 @@ void GuiTabular::updateContents()
 	}
 
 	row_set = tabular_.getRowOfLTLastFoot(row, ltt);
+	// check if setting a last footer is allowed
+	// additionally check lastfooterNoContentsCB because when this is
+	// the case a last footer makes no sense
+	lastfooterStatusCB->setEnabled(
+		funcEnabled(Tabular::SET_LTLASTFOOT)
+		&& !lastfooterNoContentsCB->isChecked());
 	lastfooterStatusCB->setChecked(row_set);
 	if (ltt.set && (!ltt.empty || !use_empty)) {
 		lastfooterBorderAboveCB->setChecked(ltt.topDL);
@@ -919,9 +959,11 @@ void GuiTabular::closeGUI()
 	docstring sa2;
 
 	if (multicol)
-		sa2 = getAlignSpecial(tabular_, cell, Tabular::SET_SPECIAL_MULTI);
+		sa2 = getAlignSpecial(tabular_, cell,
+			Tabular::SET_SPECIAL_MULTI);
 	else
-		sa2 = getAlignSpecial(tabular_, cell, Tabular::SET_SPECIAL_COLUMN);
+		sa2 = getAlignSpecial(tabular_, cell,
+			Tabular::SET_SPECIAL_COLUMN);
 
 	if (sa1 != sa2) {
 		if (multicol)
@@ -991,7 +1033,8 @@ bool GuiTabular::initialiseParams(string const & data)
 		// assume that it is "ours"
 		for (int i = cur.depth() - 1; i >= 0; --i)
 			if (cur[i].inset().lyxCode() == TABULAR_CODE) {
-				current_inset = static_cast<InsetTabular const *>(&cur[i].inset());
+				current_inset =
+					static_cast<InsetTabular const *>(&cur[i].inset());
 				active_cell_ = cur[i].idx();
 				break;
 			}
@@ -1011,8 +1054,9 @@ bool GuiTabular::initialiseParams(string const & data)
 
 void GuiTabular::clearParams()
 {
-	// This function is also called when LyX is closing and the dialog is
-	// still open. At that time, the buffer might not be available anymore.
+	// This function is also called when LyX is closing and the dialog
+	// is still open. At that time, the buffer might not be available
+	// anymore.
 	if (isBufferAvailable()) {
 		InsetTabular tmp(const_cast<Buffer &>(buffer()));
 		tabular_ = tmp.tabular;
