@@ -16,7 +16,7 @@
 #include "BufferParams.h"
 #include "BufferView.h"
 #include "BranchList.h"
-#include "Color.h"
+#include "ColorSet.h"
 #include "Counters.h"
 #include "Cursor.h"
 #include "DispatchResult.h"
@@ -29,6 +29,7 @@
 
 #include "support/debug.h"
 #include "support/gettext.h"
+#include "support/lstrings.h"
 
 #include "frontends/Application.h"
 
@@ -75,21 +76,35 @@ void InsetBranch::read(Lexer & lex)
 }
 
 
-docstring InsetBranch::toolTip(BufferView const &, int, int) const
+docstring InsetBranch::toolTip(BufferView const & bv, int x, int y) const
 {
-	return _("Branch: ") + params_.branch;
+	docstring const status = isBranchSelected() ? 
+		_("active") : _("non-active");
+	docstring const heading = 
+		support::bformat(_("Branch (%1$s): %2$s"), status, params_.branch);
+	docstring const contents = InsetCollapsable::toolTip(bv, x, y);
+	if (isOpen(bv) || contents.empty())
+		return heading;
+	else
+		return heading + from_ascii("\n") + contents;
 }
 
 
 docstring const InsetBranch::buttonLabel(BufferView const & bv) const
 {
 	docstring s = _("Branch: ") + params_.branch;
+	Buffer const & realbuffer = *buffer().masterBuffer();
+	BranchList const & branchlist = realbuffer.params().branchlist();
+	if (!branchlist.find(params_.branch)
+	    && buffer().params().branchlist().find(params_.branch))
+		s = _("Branch (child only): ") + params_.branch;
 	if (!params_.branch.empty()) {
 		// FIXME UNICODE
 		ColorCode c = lcolor.getFromLyXName(to_utf8(params_.branch));
 		if (c == Color_none)
 			s = _("Undef: ") + s;
 	}
+	s = char_type(isBranchSelected() ? 0x2714 : 0x2716) + s;
 	if (decoration() == InsetLayout::CLASSIC)
 		return isOpen(bv) ? s : getNewLabel(s);
 	else
@@ -97,10 +112,10 @@ docstring const InsetBranch::buttonLabel(BufferView const & bv) const
 }
 
 
-ColorCode InsetBranch::backgroundColor() const
+ColorCode InsetBranch::backgroundColor(PainterInfo const & pi) const
 {
 	if (params_.branch.empty())
-		return Inset::backgroundColor();
+		return Inset::backgroundColor(pi);
 	// FIXME UNICODE
 	ColorCode c = lcolor.getFromLyXName(to_utf8(params_.branch));
 	if (c == Color_none)
@@ -128,13 +143,6 @@ void InsetBranch::doDispatch(Cursor & cur, FuncRequest & cmd)
 		break;
 	}
 
-	case LFUN_MOUSE_PRESS:
-		if (cmd.button() != mouse_button::button3)
-			InsetCollapsable::doDispatch(cur, cmd);
-		else
-			cur.undispatched();
-		break;
-
 	case LFUN_INSET_DIALOG_UPDATE:
 		cur.bv().updateDialog("branch", params2string(params()));
 		break;
@@ -283,7 +291,7 @@ void InsetBranch::addToToc(DocIterator const & cpit)
 
 	Toc & toc = buffer().tocBackend().toc("branch");
 	docstring const str = params_.branch + ": " + text().getPar(0).asString();
-	toc.push_back(TocItem(pit, 0, str));
+	toc.push_back(TocItem(pit, 0, str, toolTipText()));
 	// Proceed with the rest of the inset.
 	InsetCollapsable::addToToc(cpit);
 }
