@@ -107,6 +107,8 @@ public:
 	InsetExternalParams const & params() const;
 	///
 	void setParams(InsetExternalParams const &);
+	/// Update not loaded previews
+	void updatePreview();
 	/// \returns the number of rows (\n's) of generated code.
 	int latex(odocstream &, OutputParams const &) const;
 	///
@@ -134,7 +136,7 @@ private:
 	/// Update needed features for this inset.
 	void validate(LaTeXFeatures & features) const;
 	///
-	void addPreview(graphics::PreviewLoader &) const;
+	void addPreview(DocIterator const &, graphics::PreviewLoader &) const;
 	///
 	void edit(Cursor & cur, bool front, EntryDirection entry_from);
 	///
