@@ -23,17 +23,16 @@ namespace lyx {
 class InsetFootlike : public InsetCollapsable {
 public:
 	///
-	InsetFootlike(BufferParams const &);
+	InsetFootlike(Buffer const &);
+private:
 	///
-	InsetFootlike(InsetFootlike const &);
-	///
-	bool metrics(MetricsInfo &, Dimension &) const;
+	void metrics(MetricsInfo &, Dimension &) const;
 	///
 	void draw(PainterInfo & pi, int x, int y) const;
 	///
-	void write(Buffer const & buf, std::ostream & os) const;
+	void write(std::ostream & os) const;
 	///
-	bool insetAllowed(Inset::Code) const;
+	bool insetAllowed(InsetCode) const;
 	/** returns true if, when outputing LaTeX, font changes should
 	    be closed before generating this inset. This is needed for
 	    insets that may contain several paragraphs */
