@@ -41,10 +41,13 @@ public:
 	///
 	bool isLabeled() const { return true; }
 	///
-	docstring screenLabel() const;
+	docstring screenLabel() const { return screen_label_; }
 	///
 	EDITABLE editable() const { return IS_EDITABLE; }
 	///
+	docstring toolTip(BufferView const &, int, int) const
+		{ return tooltip_; }
+	///
 	InsetCode lyxCode() const { return REF_CODE; }
 	///
 	DisplayType display() const { return Inline; }
@@ -76,8 +79,12 @@ private:
 	Inset * clone() const { return new InsetRef(*this); }
 	///
 	bool isLatex;
+	/// Force inset into LTR environment if surroundings are RTL
+	bool forceLTR() const { return true; }
 	///
 	mutable docstring screen_label_;
+	///
+	mutable docstring tooltip_;
 };
 
 } // namespace lyx
