@@ -3,7 +3,7 @@
  * This file is part of LyX, the document processor.
  * Licence details can be found in the file COPYING.
  *
- * \author Jrgen Vigna
+ * \author Jürgen Vigna
  *
  * Full author contact details are available in file CREDITS.
  */
@@ -537,7 +537,8 @@ void InsetText::addToToc(DocIterator const & cdit)
 			// insert this into the table of contents
 			if (tocstring.empty())
 				tocstring = par.asString(AS_STR_LABEL | AS_STR_INSETS);
-			toc.push_back(TocItem(dit, toclevel - min_toclevel, tocstring));
+			toc.push_back(TocItem(dit, toclevel - min_toclevel,
+				tocstring, tocstring));
 		}
 		
 		// And now the list of changes.
@@ -636,4 +637,17 @@ docstring InsetText::contextMenu(BufferView const &, int, int) const
 }
 
 
+
+docstring InsetText::toolTipText() const
+{
+	OutputParams rp(&buffer().params().encoding());
+	odocstringstream ods;
+	// do not remove InsetText::, otherwise there
+	// will be no tooltip text for InsetNotes
+	InsetText::plaintext(ods, rp);
+	docstring const content_tip = ods.str();
+	return support::wrapParas(content_tip, 4);
+}
+
+
 } // namespace lyx
