@@ -12,7 +12,6 @@
 
 #include "RenderButton.h"
 
-#include "Color.h"
 #include "MetricsInfo.h"
 
 #include "frontends/FontMetrics.h"
@@ -21,18 +20,15 @@
 
 namespace lyx {
 
-using std::string;
-using std::auto_ptr;
-
 
 RenderButton::RenderButton()
 	: editable_(false)
 {}
 
 
-auto_ptr<RenderBase> RenderButton::clone(Inset const *) const
+RenderBase * RenderButton::clone(Inset const *) const
 {
-	return auto_ptr<RenderBase>(new RenderButton(*this));
+	return new RenderButton(*this);
 }
 
 
@@ -43,9 +39,9 @@ void RenderButton::update(docstring const & text, bool editable)
 }
 
 
-bool RenderButton::metrics(MetricsInfo &, Dimension & dim) const
+void RenderButton::metrics(MetricsInfo &, Dimension & dim) const
 {
-	Font font(Font::ALL_SANE);
+	FontInfo font = sane_font;
 	font.decSize();
 	frontend::FontMetrics const & fm =
 		theFontMetrics(font);
@@ -56,25 +52,22 @@ bool RenderButton::metrics(MetricsInfo &, Dimension & dim) const
 		fm.rectText(text_, dim.wid, dim.asc, dim.des);
 
 	dim.wid += 4;
-	if (dim_ == dim)
-		return false;
 	dim_ = dim;
-	return true;
 }
 
 
 void RenderButton::draw(PainterInfo & pi, int x, int y) const
 {
 	// Draw it as a box with the LaTeX text
-	Font font(Font::ALL_SANE);
-	font.setColor(Color::command);
+	FontInfo font = sane_font;
+	font.setColor(Color_command);
 	font.decSize();
 
 	if (editable_) {
 		pi.pain.buttonText(x + 2, y, text_, font, renderState());
 	} else {
 		pi.pain.rectText(x + 2, y, text_, font,
-				 Color::commandbg, Color::commandframe);
+				 Color_commandbg, Color_commandframe);
 	}
 }
 
