@@ -25,7 +25,7 @@ public:
 	///
 	explicit InsetMathDots(latexkeys const * l);
 	///
-	bool metrics(MetricsInfo & mi, Dimension & dim) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void draw(PainterInfo & pi, int x, int y) const;
 	///
@@ -38,7 +38,7 @@ protected:
 	///
 	latexkeys const * key_;
 private:
-	virtual std::auto_ptr<Inset> doClone() const;
+	virtual Inset * clone() const;
 };
 
 } // namespace lyx
