@@ -24,7 +24,7 @@ namespace lyx {
 class InsetMathEnv : public InsetMathNest {
 public:
 	///
-	InsetMathEnv(docstring const & name_);
+	InsetMathEnv(Buffer * buf, docstring const & name_);
 	///
 	void draw(PainterInfo &, int x, int y) const;
 	///
@@ -32,12 +32,12 @@ public:
 	/// write normalized content
 	void normalize(NormalStream & ns) const;
 	///
-	bool metrics(MetricsInfo & mi, Dimension & dim) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void infoize(odocstream & os) const;
 
 private:
-	virtual std::auto_ptr<Inset> doClone() const;
+	virtual Inset * clone() const;
 	/// name of that environment
 	docstring name_;
 };
