@@ -35,14 +35,16 @@ namespace lyx {
 /////////////////////////////////////////////////////////////////////
 
 
-InsetMathFracBase::InsetMathFracBase(idx_type ncells)
-	: InsetMathNest(ncells)
+InsetMathFracBase::InsetMathFracBase(Buffer * buf, idx_type ncells)
+	: InsetMathNest(buf, ncells)
 {}
 
 
 bool InsetMathFracBase::idxUpDown(Cursor & cur, bool up) const
 {
-	InsetMath::idx_type target = !up; // up ? 0 : 1, since upper cell has idx 0
+	// If we only have one cell, target = 0, otherwise
+	// target = up ? 0 : 1, since upper cell has idx 0
+	InsetMath::idx_type target = nargs() > 1 ? !up : 0;
 	if (cur.idx() == target)
 		return false;
 	cur.idx() = target;
@@ -59,8 +61,8 @@ bool InsetMathFracBase::idxUpDown(Cursor & cur, bool up) const
 /////////////////////////////////////////////////////////////////////
 
 
-InsetMathFrac::InsetMathFrac(Kind kind, InsetMath::idx_type ncells)
-	: InsetMathFracBase(ncells), kind_(kind)
+InsetMathFrac::InsetMathFrac(Buffer * buf, Kind kind, InsetMath::idx_type ncells)
+	: InsetMathFracBase(buf, ncells), kind_(kind)
 {}
 
 
@@ -242,12 +244,12 @@ void InsetMathFrac::draw(PainterInfo & pi, int x, int y) const
 		pi.pain.line(xx + dim0.wid,
 				y + dim.des - 2,
 				xx + dim0.wid + 5,
-				y - dim.asc + 2, Color_math);
+				y - dim.asc + 2, pi.base.font.color());
 	}
 	if (kind_ == FRAC || kind_ == CFRAC || kind_ == CFRACLEFT
 		|| kind_ == CFRACRIGHT || kind_ == OVER)
 		pi.pain.line(x + 1, y - 5,
-				x + dim.wid - 2, y - 5, Color_math);
+				x + dim.wid - 2, y - 5, pi.base.font.color());
 	drawMarkers(pi, x, y);
 }
 
@@ -373,6 +375,8 @@ void InsetMathFrac::validate(LaTeXFeatures & features) const
 {
 	if (kind_ == NICEFRAC || kind_ == UNITFRAC || kind_ == UNIT)
 		features.require("units");
+	if (kind_ == CFRAC || kind_ == CFRACLEFT || kind_ == CFRACRIGHT)
+		features.require("amsmath");
 	InsetMathNest::validate(features);
 }
 
@@ -499,8 +503,8 @@ void InsetMathTFrac::validate(LaTeXFeatures & features) const
 /////////////////////////////////////////////////////////////////////
 
 
-InsetMathBinom::InsetMathBinom(Kind kind)
-	: kind_(kind)
+InsetMathBinom::InsetMathBinom(Buffer * buf, Kind kind)
+	: InsetMathFracBase(buf), kind_(kind)
 {}
 
 
