@@ -634,7 +634,7 @@ void InsetMathGrid::drawT(TextPainter & /*pain*/, int /*x*/, int /*y*/) const
 }
 
 
-docstring InsetMathGrid::eolString(row_type row, bool fragile) const
+docstring InsetMathGrid::eolString(row_type row, bool fragile, bool last_eoln) const
 {
 	docstring eol;
 
@@ -652,7 +652,7 @@ docstring InsetMathGrid::eolString(row_type row, bool fragile) const
 	}
 
 	// only add \\ if necessary
-	if (eol.empty() && row + 1 == nrows())
+	if (eol.empty() && row + 1 == nrows() && (nrows() == 1 || !last_eoln))
 		return docstring();
 
 	return (fragile ? "\\protect\\\\" : "\\\\") + eol;
@@ -990,19 +990,23 @@ void InsetMathGrid::write(WriteStream & os) const
 		// unless there are vertical lines
 		col_type lastcol = 0;
 		bool emptyline = true;
-		for (col_type col = 0; col < ncols(); ++col)
-			if (!cell(index(row, col)).empty()
-				  || colinfo_[col + 1].lines_) {
+		bool last_eoln = true;
+		for (col_type col = 0; col < ncols(); ++col) {
+			bool const empty_cell = cell(index(row, col)).empty();
+			if (!empty_cell)
+				last_eoln = false;
+			if (!empty_cell || colinfo_[col + 1].lines_) {
 				lastcol = col + 1;
 				emptyline = false;
 			}
+		}
 		for (col_type col = 0; col < lastcol; ++col) {
 			os << cell(index(row, col));
 			if (os.pendingBrace())
 				ModeSpecifier specifier(os, TEXT_MODE);
 			os << eocString(col, lastcol);
 		}
-		eol = eolString(row, os.fragile());
+		eol = eolString(row, os.fragile(), last_eoln);
 		os << eol;
 		// append newline only if line wasn't completely empty
 		// and this was not the last line in the grid
