@@ -230,7 +230,7 @@ protected:
 	/// returns y offset of cell compared to inset
 	int cellYOffset(idx_type idx) const;
 	/// returns proper 'end of line' code for LaTeX
-	virtual docstring eolString(row_type row, bool fragile) const;
+	virtual docstring eolString(row_type row, bool fragile, bool last_eoln) const;
 	/// returns proper 'end of column' code for LaTeX
 	virtual docstring eocString(col_type col, col_type lastcol) const;
 	/// splits cells and shifts right part to the next cell
