@@ -38,6 +38,7 @@
 #include "FuncRequest.h"
 #include "Language.h"
 #include "LyXRC.h"
+#include "MacroTable.h"
 #include "OutputParams.h"
 #include "ParIterator.h"
 #include "sgml.h"
@@ -328,6 +329,12 @@ docstring InsetMathHull::standardFont() const
 }
 
 
+docstring InsetMathHull::standardColor() const
+{
+	return from_ascii(type_ == hullNone ? "foreground" : "math");
+}
+
+
 bool InsetMathHull::previewState(BufferView * bv) const
 {
 	if (!editing(bv) && RenderPreview::status() == LyXRC::PREVIEW_ON) {
@@ -385,6 +392,14 @@ void InsetMathHull::metrics(MetricsInfo & mi, Dimension & dim) const
 }
 
 
+ColorCode InsetMathHull::backgroundColor(PainterInfo const & pi) const
+{
+	if (previewState(pi.base.bv))
+		return Color_background;
+	return Color_mathbg;
+}
+
+
 void InsetMathHull::drawBackground(PainterInfo & pi, int x, int y) const
 {
 	Dimension const dim = dimension(*pi.base.bv);
@@ -404,8 +419,11 @@ void InsetMathHull::draw(PainterInfo & pi, int x, int y) const
 		return;
 	}
 
+	bool const really_change_color = pi.base.font.color() == Color_none;
+	ColorChanger dummy0(pi.base.font, standardColor(), really_change_color);
 	FontSetChanger dummy1(pi.base, standardFont());
 	StyleChanger dummy2(pi.base, display() ? LM_ST_DISPLAY : LM_ST_TEXT);
+
 	InsetMathGrid::draw(pi, x + 1, y);
 
 	if (numberedType()) {
@@ -473,22 +491,50 @@ void InsetMathHull::initUnicodeMath() const
 }
 
 
-void InsetMathHull::addPreview(graphics::PreviewLoader & ploader) const
+void InsetMathHull::addPreview(DocIterator const & inset_pos,
+	graphics::PreviewLoader & ploader) const
 {
 	if (RenderPreview::status() == LyXRC::PREVIEW_ON) {
-		docstring const snippet = latexString(*this);
-		preview_->addPreview(snippet, ploader);
+		preparePreview(inset_pos, ploader.buffer());
 	}
 }
 
 
-bool InsetMathHull::notifyCursorLeaves(Cursor const & /*old*/, Cursor & cur)
+void InsetMathHull::preparePreview(DocIterator const & pos,
+	Buffer const & buffer) const  
+{
+	// collect macros at this position  
+	MacroNameSet macros;  
+	buffer.listMacroNames(macros);  
+	MacroNameSet::iterator it = macros.begin();  
+	MacroNameSet::iterator end = macros.end();  
+	odocstringstream macro_preamble;  
+	for (; it != end; ++it) {  
+		MacroData const * data = buffer.getMacro(*it, pos, true);  
+		if (data) {  
+			data->write(macro_preamble, true);  
+			macro_preamble << endl;  
+		}
+	}  
+
+	docstring const snippet = macro_preamble.str() + latexString(*this);  
+	LYXERR(Debug::MACROS, "Preview snippet: " << snippet);  
+	preview_->addPreview(snippet, buffer);  
+}
+
+
+void InsetMathHull::reloadPreview(DocIterator const & pos,
+	Buffer const & buffer) const
+{
+	preparePreview(pos, buffer);
+	preview_->startLoading(buffer);
+}
+
+
+bool InsetMathHull::notifyCursorLeaves(Cursor const & old, Cursor & cur)
 {
 	if (RenderPreview::status() == LyXRC::PREVIEW_ON) {
-		Buffer const & buffer = cur.buffer();
-		docstring const snippet = latexString(*this);
-		preview_->addPreview(snippet, buffer);
-		preview_->startLoading(buffer);
+		reloadPreview(old, cur.buffer());
 		cur.updateFlags(Update::Force);
 	}
 	return false;
@@ -1030,16 +1076,19 @@ void InsetMathHull::mutate(HullType newtype)
 }
 
 
-docstring InsetMathHull::eolString(row_type row, bool fragile) const
+docstring InsetMathHull::eolString(row_type row, bool fragile, bool last_eoln) const
 {
 	docstring res;
 	if (numberedType()) {
 		if (label_[row] && !nonum_[row])
-			res += "\\label{" + label_[row]->getParam("name") + '}';
+			res += "\\label{" +
+			    escape(label_[row]->getParam("name")) + '}';
 		if (nonum_[row] && (type_ != hullMultline))
 			res += "\\nonumber ";
 	}
-	return res + InsetMathGrid::eolString(row, fragile);
+	// Never add \\ on the last empty line of eqnarray and friends
+	last_eoln = false;
+	return res + InsetMathGrid::eolString(row, fragile, last_eoln);
 }
 
 
