@@ -25,11 +25,11 @@ class latexkeys;
 class InsetMathSize : public InsetMathNest {
 public:
 	///
-	explicit InsetMathSize(latexkeys const * l);
+	explicit InsetMathSize(Buffer * buf, latexkeys const * l);
 	/// we write extra braces in any case...
 	bool extraBraces() const { return true; }
 	///
-	bool metrics(MetricsInfo & mi, Dimension & dim) const;
+	void metrics(MetricsInfo & mi, Dimension & dim) const;
 	///
 	void draw(PainterInfo &, int x, int y) const;
 
@@ -40,7 +40,7 @@ public:
 	///
 	void infoize(odocstream & os) const;
 private:
-	virtual std::auto_ptr<Inset> doClone() const;
+	virtual Inset * clone() const;
 	///
 	latexkeys const * key_;
 	///
