@@ -58,6 +58,7 @@ following hack as starting point to write some macros:
 #include "InsetMathSpace.h"
 #include "InsetMathSplit.h"
 #include "InsetMathSqrt.h"
+#include "InsetMathString.h"
 #include "InsetMathTabular.h"
 #include "MathMacroTemplate.h"
 #include "MathFactory.h"
@@ -212,7 +213,7 @@ bool addCol(InsetMathGrid & grid, InsetMathGrid::col_type & cellcol)
 
 
 /*!
- * Check wether the last row is empty and remove it if yes.
+ * Check whether the last row is empty and remove it if yes.
  * Otherwise the following code
  * \verbatim
 \begin{array}{|c|c|}
@@ -223,6 +224,8 @@ bool addCol(InsetMathGrid & grid, InsetMathGrid::col_type & cellcol)
  * \endverbatim
  * will result in a grid with 3 rows (+ the dummy row that is always present),
  * because the last '\\' opens a new row.
+ * Note that this is only needed for inner-hull grid types, such as array
+ * or aligned, but not for outer-hull grid types, such as eqnarray or align.
  */
 void delEmptyLastRow(InsetMathGrid & grid)
 {
@@ -239,6 +242,19 @@ void delEmptyLastRow(InsetMathGrid & grid)
 }
 
 
+/*!
+ * Tell whether the environment name corresponds to an inner-hull grid type.
+ */
+bool innerHull(docstring const & name)
+{
+	// For [bB]matrix, [vV]matrix, and pmatrix we can check the suffix only
+	return name == "array" || name == "cases" || name == "aligned"
+		|| name == "alignedat" || name == "gathered" || name == "split"
+		|| name == "subarray" || name == "tabular" || name == "matrix"
+		|| name.substr(1) == "matrix";
+}
+
+
 // These are TeX's catcodes
 enum CatCode {
 	catEscape,     // 0    backslash
@@ -612,6 +628,8 @@ void Parser::tokenize(docstring const & buffer)
 				if (!is) {
 					error("unexpected end of input");
 				} else {
+					if (c == '\n')
+						c = ' ';
 					docstring s(1, c);
 					if (catcode(c) == catLetter) {
 						// collect letters
@@ -933,6 +951,14 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 			// in an unreliable way. See this thread
 			// http://www.mail-archive.com/lyx-devel%40lists.lyx.org/msg104917.html
 			// for more details.
+			// However, we remove empty braces because they look
+			// ugly on screen and we are sure that they were added
+			// by the write() method (and will be re-added on save).
+			if (p->nuc().size() == 1 &&
+			    p->nuc().back()->asBraceInset() &&
+			    p->nuc().back()->asBraceInset()->cell(0).empty())
+				p->nuc().erase(0);
+
 			parse(p->cell(p->idxOfScript(up)), FLAG_ITEM, mode);
 			if (limits) {
 				p->limits(limits);
@@ -1232,7 +1258,7 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 					// probably need to refine this test.
 					// Right now we only have to test for
 					// single line hull insets.
-					if (grid.nrows() > 1)
+					if (grid.nrows() > 1 && innerHull(name))
 						delEmptyLastRow(grid);
 					return success_;
 				}
@@ -1306,11 +1332,15 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 		}
 #endif
 
-		else if (t.cs() == "limits")
-			limits = 1;
-
-		else if (t.cs() == "nolimits")
-			limits = -1;
+		else if (t.cs() == "limits" || t.cs() == "nolimits") {
+			CatCode cat = nextToken().cat();
+			if (cat == catSuper || cat == catSub)
+				limits = t.cs() == "limits" ? 1 : -1;
+			else {
+				MathAtom at = createInsetMath(t.cs(), buf);
+				cell->push_back(at);
+			}
+		}
 
 		else if (t.cs() == "nonumber") {
 			if (grid.asHullInset())
@@ -1394,8 +1424,14 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 		else if (t.cs() == "ref" || t.cs() == "eqref" || t.cs() == "prettyref"
 			  || t.cs() == "pageref" || t.cs() == "vpageref" || t.cs() == "vref") {
 			cell->push_back(MathAtom(new InsetMathRef(buf, t.cs())));
-			parse(cell->back().nucleus()->cell(1), FLAG_OPTION, mode);
-			parse(cell->back().nucleus()->cell(0), FLAG_ITEM, mode);
+			docstring const opt = parse_verbatim_option();
+			docstring const ref = parse_verbatim_item();
+			if (!opt.empty()) {
+				cell->back().nucleus()->cell(1).push_back(
+					MathAtom(new InsetMathString(opt)));
+			}
+			cell->back().nucleus()->cell(0).push_back(
+					MathAtom(new InsetMathString(ref)));
 		}
 
 		else if (t.cs() == "left") {
@@ -1660,6 +1696,11 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 		else if (t.cs() == "substack") {
 			cell->push_back(createInsetMath(t.cs(), buf));
 			parse2(cell->back(), FLAG_ITEM, mode, false);
+			// Delete empty last row if present
+			InsetMathGrid & subgrid =
+				*(cell->back().nucleus()->asGridInset());
+			if (subgrid.nrows() > 1)
+				delEmptyLastRow(subgrid);
 		}
 
 		else if (t.cs() == "xymatrix") {
@@ -1668,6 +1709,11 @@ bool Parser::parse1(InsetMathGrid & grid, unsigned flags,
 				os << getToken().asInput();
 			cell->push_back(createInsetMath(t.cs() + os.str(), buf));
 			parse2(cell->back(), FLAG_ITEM, mode, false);
+			// Delete empty last row if present
+			InsetMathGrid & subgrid =
+				*(cell->back().nucleus()->asGridInset());
+			if (subgrid.nrows() > 1)
+				delEmptyLastRow(subgrid);
 		}
 
 		else if (t.cs() == "framebox" || t.cs() == "makebox") {
