@@ -660,14 +660,20 @@ void RowPainter::paintLast()
 		FontInfo const font = labelFont();
 		FontMetrics const & fm = theFontMetrics(font);
 		docstring const & str = par_.layout().endlabelstring();
-		double const x = is_rtl ?
-			x_ - fm.width(str)
-			: - text_metrics_.rightMargin(pm_) - row_.width();
+		double const x = is_rtl ? x_ - fm.width(str) : x_;
 		pi_.pain.text(int(x), yo_, str, font);
 		break;
 	}
 
 	case END_LABEL_NO_LABEL:
+		if (lyxrc.paragraph_markers && size_type(pit_ + 1) < pars_.size()) {
+			docstring const s = docstring(1, char_type(0x00B6));
+			FontInfo f = FontInfo();
+			FontMetrics const & fm = theFontMetrics(f);
+			f.setColor(Color_paragraphmarker);
+			pi_.pain.text(int(x_), yo_, s, f);
+			x_ += fm.width(s);
+		}
 		break;
 	}
 }
