@@ -11,21 +11,14 @@
 #include <config.h>
 
 #include "support/FileMonitor.h"
-#include "support/filetools.h"
-#include "support/FileName.h"
-#include "support/lyxlib.h"
 
-// FIXME Interface violation
-#include "frontends/Timeout.h"
+#include "support/FileName.h"
+#include "support/Timeout.h"
 
 #include <boost/bind.hpp>
-#include <boost/filesystem/operations.hpp>
 #include <boost/signals/trackable.hpp>
 
-
-using std::string;
-
-namespace fs = boost::filesystem;
+using namespace std;
 
 namespace lyx {
 namespace support {
@@ -63,7 +56,9 @@ FileMonitor::FileMonitor(FileName const & file_with_path, int interval)
 
 
 FileMonitor::~FileMonitor()
-{}
+{
+	delete pimpl_;
+}
 
 
 void FileMonitor::reset(FileName const & file_with_path) const
@@ -93,11 +88,11 @@ void FileMonitor::start() const
 	if (monitoring())
 		return;
 
-	if (!doesFileExist(pimpl_->filename_))
+	if (!pimpl_->filename_.exists())
 		return;
 
-	pimpl_->timestamp_ = fs::last_write_time(pimpl_->filename_.toFilesystemEncoding());
-	pimpl_->checksum_ = sum(pimpl_->filename_);
+	pimpl_->timestamp_ = pimpl_->filename_.lastModified();
+	pimpl_->checksum_ = pimpl_->filename_.checksum();
 
 	if (pimpl_->timestamp_ && pimpl_->checksum_) {
 		pimpl_->timer_.start();
@@ -127,7 +122,7 @@ unsigned long FileMonitor::checksum() const
 	// If we aren't actively monitoring the file, then recompute the
 	// checksum explicitly.
 	if (!pimpl_->timer_.running() && !pimpl_->filename_.empty())
-		return sum(pimpl_->filename_);
+		return pimpl_->filename_.checksum();
 
 	return pimpl_->checksum_;
 }
@@ -158,18 +153,18 @@ void FileMonitor::Impl::monitorFile()
 {
 	bool changed = false;
 
-	if (!doesFileExist(filename_)) {
+	if (!filename_.exists()) {
 		changed = timestamp_ || checksum_;
 		timestamp_ = 0;
 		checksum_ = 0;
 
 	} else {
-		time_t const new_timestamp = fs::last_write_time(filename_.toFilesystemEncoding());
+		time_t const new_timestamp = filename_.lastModified();
 
 		if (new_timestamp != timestamp_) {
 			timestamp_ = new_timestamp;
 
-			unsigned long const new_checksum = sum(filename_);
+			unsigned long const new_checksum = filename_.checksum();
 			if (new_checksum != checksum_) {
 				checksum_ = new_checksum;
 				changed = true;
