@@ -18,8 +18,8 @@
 #include <csignal>
 
 #ifdef _WIN32
-#include "debug.h"
-#include "os.h"
+#include "support/debug.h"
+#include "support/os.h"
 
 #include <windows.h>
 #include <cerrno>
@@ -34,11 +34,11 @@ int support::kill(int pid, int sig)
 		return -raise(sig);
 	HANDLE hProcess = OpenProcess(PROCESS_ALL_ACCESS, TRUE, pid);
 	if (!hProcess) {
-		lyxerr << "kill OpenProcess failed!" << std::endl;
+		LYXERR0("kill OpenProcess failed!");
 		return -1;
 	}
 	if (!TerminateProcess(hProcess, sig)) {
-		lyxerr << "kill process failed!" << std::endl;
+		LYXERR0("kill process failed!");
 		CloseHandle(hProcess);
 		return -1;
 	}
