@@ -649,6 +649,7 @@ basic_string<Ch> const subst_char(basic_string<Ch> const & a,
 	return tmp;
 }
 
+
 /// Substitute all \a oldchar with \a newchar
 docstring const subst_char(docstring const & a,
 	docstring::value_type oldchar, docstring::value_type newchar)
@@ -680,6 +681,7 @@ String const subst_string(String const & a,
 	return lstr;
 }
 
+
 docstring const subst_string(docstring const & a,
 		docstring const & oldstr, docstring const & newstr)
 {
@@ -725,6 +727,19 @@ docstring const subst(docstring const & a,
 }
 
 
+/// Count all occurences of char \a chr inside \a str
+int count_char(docstring const & str, docstring::value_type chr)
+{
+	int count = 0;
+	docstring::const_iterator lit = str.begin();
+	docstring::const_iterator end = str.end();
+	for (; lit != end; ++lit)
+		if ((*lit) == chr)
+			count++;
+	return count;
+}
+
+
 docstring const trim(docstring const & a, char const * p)
 {
 	LASSERT(p, /**/);
@@ -958,8 +973,8 @@ vector<docstring> wrapToVec(docstring const & str, int ind,
 	vector<docstring> retval;
 	while (s.size() > width) {
 		// find the last space within the first 'width' chars
-		int i = s.find_last_of(' ', width - 1);
-		if (i == docstring::npos || i <= ind) {
+		size_t const i = s.find_last_of(' ', width - 1);
+		if (i == docstring::npos || i <= size_t(ind)) {
 			// no space found
 			s = s.substr(0, width - 3) + "...";
 			break;
@@ -1000,10 +1015,10 @@ docstring wrapParas(docstring const & str, int const indent,
 	vector<docstring>::iterator en = pars.end();
 	for (; it != en; ++it) {
 		vector<docstring> tmp = wrapToVec(*it, indent, width);
-		int const nlines = tmp.size();
+		size_t const nlines = tmp.size();
 		if (nlines == 0)
 			continue;
-		int const curlines = retval.size();
+		size_t const curlines = retval.size();
 		if (maxlines > 0 && curlines + nlines >= maxlines) {
 			tmp.resize(maxlines - curlines - 1);
 			tmp.push_back(from_ascii("..."));
