@@ -170,6 +170,9 @@ std::string const subst(std::string const & a,
 docstring const subst(docstring const & a,
 		docstring const & oldstr, docstring const & newstr);
 
+/// Count all occurences of char \a chr inside \a str
+int count_char(docstring const & str, docstring::value_type chr);
+
 /** Trims characters off the end and beginning of a string.
     \code
     trim("ccabccc", "c") == "ab".
@@ -221,11 +224,30 @@ std::string const split(std::string const & a, char delim);
 
 /// Same as split but uses the last delim.
 std::string const rsplit(std::string const & a, std::string & piece, char delim);
+docstring const rsplit(docstring const & a, char_type delim);
 
 /// Escapes non ASCII chars and other problematic characters that cause
 /// problems in latex labels.
 docstring const escape(docstring const & lab);
 
+/// Word-wraps the provided docstring, returning a line-broken string
+/// of width no wider than width, with the string broken at spaces. 
+/// If the string cannot be broken appropriately, it returns something 
+/// with "..." at the end, again no wider than width.
+/// We assume here that str does not contain newlines.
+/// If indent is positive, then the first line is indented that many 
+/// spaces. If it is negative, then successive lines are indented, as
+/// if the first line were "outdented".
+docstring wrap(docstring const & str, int const indent = 0,
+               size_t const width = 80);
+
+/// Like the preceding, except it is intended to operate on strings
+/// that may contain embedded newlines.
+/// \param numlines Don't return more than numlines lines. If numlines
+///    is 0, we return everything.
+docstring wrapParas(docstring const & str, int const indent = 0,
+                    size_t const width = 80, size_t const maxlines = 10);
+
 /// gives a vector of stringparts which have the delimiter delim
 /// If \p keepempty is true, empty strings will be pushed to the vector as well
 std::vector<std::string> const getVectorFromString(std::string const & str,
@@ -234,9 +256,11 @@ std::vector<std::string> const getVectorFromString(std::string const & str,
 std::vector<docstring> const getVectorFromString(docstring const & str,
 		docstring const & delim = from_ascii(","), bool keepempty = false);
 
-// the same vice versa
+/// the same vice versa
 std::string const getStringFromVector(std::vector<std::string> const & vec,
 				 std::string const & delim = std::string(","));
+docstring const getStringFromVector(std::vector<docstring> const & vec,
+				 docstring const & delim = from_ascii(","));
 
 /// Search \p search_token in \p str and return the position if it is
 /// found, else -1. The last item in \p str must be "".
