@@ -6,6 +6,7 @@
  * \author Ruurd A. Reitsma
  * \author Claus Hentschel
  * \author Angus Leeming
+ * \author Enrico Forestieri
  *
  * Full author contact details are available in file CREDITS.
  *
@@ -23,30 +24,14 @@
 #include "support/filetools.h"
 #include "support/lstrings.h"
 #include "support/ExceptionMessage.h"
+#include "support/qstring_helpers.h"
 
 #include "support/lassert.h"
 
 #include <cstdlib>
 #include <vector>
 
-/* The GetLongPathName macro may be defined on the compiling machine,
- * but we must use a bit of trickery if the resulting executable is
- * to run on a Win95 machine.
- * Fortunately, Microsoft provide the trickery. All we need is the
- * NewAPIs.h header file, available for download from Microsoft as
- * part of the Platform SDK.
- */
-#if defined (HAVE_NEWAPIS_H)
-// This should be defined already to keep Boost.Filesystem happy.
-# if !defined (WANT_GETFILEATTRIBUTESEX_WRAPPER)
-#   error Expected WANT_GETFILEATTRIBUTESEX_WRAPPER to be defined!
-# endif
-# define WANT_GETLONGPATHNAME_WRAPPER 1
-# define COMPILE_NEWAPIS_STUBS
-# include <NewAPIs.h>
-# undef COMPILE_NEWAPIS_STUBS
-# undef WANT_GETLONGPATHNAME_WRAPPER
-#endif
+#include <QString>
 
 #include <io.h>
 #include <direct.h> // _getdrive
@@ -68,17 +53,25 @@
 #define ASSOCF_INIT_IGNOREUNKNOWN 0
 #endif
 
+extern "C" {
+extern void __wgetmainargs(int * argc, wchar_t *** argv, wchar_t *** envp,
+			   int expand_wildcards, int * new_mode);
+}
+
 using namespace std;
 
 namespace lyx {
 
-void emergencyCleanup();
+void lyx_exit(int);
 
 namespace support {
 namespace os {
 
 namespace {
 
+int argc_ = 0;
+wchar_t ** argv_ = 0;
+
 bool windows_style_tex_paths_ = true;
 
 string cygdrive = "/cygdrive";
@@ -88,7 +81,7 @@ BOOL terminate_handler(DWORD event)
 	if (event == CTRL_CLOSE_EVENT
 	    || event == CTRL_LOGOFF_EVENT
 	    || event == CTRL_SHUTDOWN_EVENT) {
-		lyx::emergencyCleanup();
+		lyx::lyx_exit(1);
 		return TRUE;
 	}
 	return FALSE;
@@ -96,7 +89,7 @@ BOOL terminate_handler(DWORD event)
 
 } // namespace anon
 
-void init(int /* argc */, char * argv[])
+void init(int argc, char * argv[])
 {
 	/* Note from Angus, 17 Jan 2005:
 	 *
@@ -154,26 +147,54 @@ void init(int /* argc */, char * argv[])
 	 * lyx is invoked as a parameter of hidecmd.exe.
 	 */
 
-	// If cygwin is detected, query the cygdrive prefix
-	HKEY regKey;
-	char buf[MAX_PATH];
-	DWORD bufSize = sizeof(buf);
-	LONG retVal;
 
-	retVal = RegOpenKeyEx(HKEY_LOCAL_MACHINE,
-			"Software\\Cygnus Solutions\\Cygwin\\mounts v2",
-			0, KEY_QUERY_VALUE, &regKey);
-	if (retVal != ERROR_SUCCESS) {
-		retVal = RegOpenKeyEx(HKEY_CURRENT_USER,
-				"Software\\Cygnus Solutions\\Cygwin\\mounts v2",
-				0, KEY_QUERY_VALUE, &regKey);
+	// Get the wide program arguments array
+	wchar_t ** envp = 0;
+	int newmode = 0;
+	__wgetmainargs(&argc_, &argv_, &envp, -1, &newmode);
+	LASSERT(argc == argc_, /**/);
+
+	// If Cygwin is detected, query the cygdrive prefix.
+	// The cygdrive prefix is needed for translating windows style paths
+	// to posix style paths in LaTeX files when the Cygwin teTeX is used.
+	int i;
+	HKEY hkey;
+	char buf[MAX_PATH];
+	DWORD bufsize = sizeof(buf);
+	LONG retval = ERROR_FILE_NOT_FOUND;
+	HKEY const mainkey[2] = { HKEY_LOCAL_MACHINE, HKEY_CURRENT_USER };
+	char const * const subkey[2] = {
+		"Software\\Cygwin\\setup",                         // Cygwin 1.7
+		"Software\\Cygnus Solutions\\Cygwin\\mounts v2\\/" // Prev. ver.
+	};
+	char const * const valuename[2] = {
+		"rootdir", // Cygwin 1.7 or later
+		"native"   // Previous versions
+	};
+	// Check for newer Cygwin versions first, then older ones
+	for (i = 0; i < 2 && retval != ERROR_SUCCESS; ++i) {
+		for (int k = 0; k < 2 && retval != ERROR_SUCCESS; ++k)
+			retval = RegOpenKey(mainkey[k], subkey[i], &hkey);
 	}
-	if (retVal == ERROR_SUCCESS) {
-		retVal = RegQueryValueEx(regKey, "cygdrive prefix", NULL, NULL,
-				(LPBYTE) buf, &bufSize);
-		RegCloseKey(regKey);
-		if ((retVal == ERROR_SUCCESS) && (bufSize <= MAX_PATH))
-			cygdrive = rtrim(string(buf), "/");
+	if (retval == ERROR_SUCCESS) {
+		// Query the Cygwin root directory
+		retval = RegQueryValueEx(hkey, valuename[i - 1],
+				NULL, NULL, (LPBYTE) buf, &bufsize);
+		RegCloseKey(hkey);
+		string const mount = string(buf) + "\\bin\\mount.exe";
+		if (retval == ERROR_SUCCESS && FileName(mount).exists()) {
+			cmd_ret const p =
+				runCommand(mount + " --show-cygdrive-prefix");
+			// The output of the mount command is as follows:
+			// Prefix              Type         Flags
+			// /cygdrive           system       binmode
+			// So, we use the inner split to pass the second line
+			// to the outer split which sets cygdrive with its
+			// contents until the first blank, discarding the
+			// unneeded return value.
+			if (p.first != -1 && prefixIs(p.second, "Prefix"))
+				split(split(p.second, '\n'), cygdrive, ' ');
+		}
 	}
 
 	// Catch shutdown events.
@@ -181,6 +202,21 @@ void init(int /* argc */, char * argv[])
 }
 
 
+string utf8_argv(int i)
+{
+	LASSERT(i < argc_, /**/);
+	return fromqstr(QString::fromWCharArray(argv_[i]));
+}
+
+
+void remove_internal_args(int i, int num)
+{
+	argc_ -= num;
+	for (int j = i; j < argc_; ++j)
+		argv_[j] = argv_[j + num];
+}
+
+
 string current_root()
 {
 	// _getdrive returns the current drive (1=A, 2=B, and so on).
@@ -257,29 +293,60 @@ string external_path(string const & p)
 }
 
 
-static string const get_long_path(string const & short_path)
+static QString const get_long_path(QString const & short_path)
 {
-	// GetLongPathName needs the path in file system encoding.
-	// We can use to_local8bit, since file system encoding and the
-	// local 8 bit encoding are identical on windows.
-	vector<char> long_path(MAX_PATH);
-	DWORD result = GetLongPathName(to_local8bit(from_utf8(short_path)).c_str(),
+	// GetLongPathNameW needs the path in utf16 encoding.
+	vector<wchar_t> long_path(MAX_PATH);
+	DWORD result = GetLongPathNameW((wchar_t *) short_path.utf16(),
 				       &long_path[0], long_path.size());
 
 	if (result > long_path.size()) {
 		long_path.resize(result);
-		result = GetLongPathName(short_path.c_str(),
+		result = GetLongPathNameW((wchar_t *) short_path.utf16(),
 					 &long_path[0], long_path.size());
 		LASSERT(result <= long_path.size(), /**/);
 	}
 
-	return (result == 0) ? short_path : to_utf8(from_filesystem8bit(&long_path[0]));
+	return (result == 0) ? short_path : QString::fromWCharArray(&long_path[0]);
+}
+
+
+static QString const get_short_path(QString const & long_path, file_access how)
+{
+	// CreateFileW and GetShortPathNameW need the path in utf16 encoding.
+	if (how == CREATE) {
+		HANDLE h = CreateFileW((wchar_t *) long_path.utf16(),
+				GENERIC_WRITE, 0, NULL, CREATE_NEW,
+				FILE_ATTRIBUTE_NORMAL, NULL);
+		if (h == INVALID_HANDLE_VALUE
+		    && GetLastError() != ERROR_FILE_EXISTS)
+			return long_path;
+		CloseHandle(h);
+	}
+	vector<wchar_t> short_path(MAX_PATH);
+	DWORD result = GetShortPathNameW((wchar_t *) long_path.utf16(),
+				       &short_path[0], short_path.size());
+
+	if (result > short_path.size()) {
+		short_path.resize(result);
+		result = GetShortPathNameW((wchar_t *) long_path.utf16(),
+					 &short_path[0], short_path.size());
+		LASSERT(result <= short_path.size(), /**/);
+	}
+
+	return (result == 0) ? long_path : QString::fromWCharArray(&short_path[0]);
 }
 
 
 string internal_path(string const & p)
 {
-	return subst(get_long_path(p), "\\", "/");
+	return subst(fromqstr(get_long_path(toqstr(p))), "\\", "/");
+}
+
+
+string safe_internal_path(string const & p, file_access how)
+{
+	return subst(fromqstr(get_short_path(toqstr(p), how)), "\\", "/");
 }
 
 
@@ -441,12 +508,13 @@ bool autoOpenFile(string const & filename, auto_open_mode const mode)
 string real_path(string const & path)
 {
 	// See http://msdn.microsoft.com/en-us/library/aa366789(VS.85).aspx
-	HANDLE hpath = CreateFile(subst(path, '/', '\\').c_str(), GENERIC_READ,
+	QString const qpath = get_long_path(toqstr(path));
+	HANDLE hpath = CreateFileW((wchar_t *) qpath.utf16(), GENERIC_READ,
 				FILE_SHARE_READ, NULL, OPEN_EXISTING, 0, NULL);
 
 	if (hpath == INVALID_HANDLE_VALUE) {
 		// The file cannot be accessed.
-		return FileName::fromFilesystemEncoding(path).absFilename();
+		return path;
 	}
 
 	// Get the file size.
@@ -456,7 +524,7 @@ string real_path(string const & path)
 	if (size_lo == 0 && size_hi == 0) {
 		// A zero-length file cannot be mapped.
 		CloseHandle(hpath);
-		return FileName::fromFilesystemEncoding(path).absFilename();
+		return path;
 	}
 
 	// Create a file mapping object.
@@ -464,7 +532,7 @@ string real_path(string const & path)
 
 	if (!hmap) {
 		CloseHandle(hpath);
-		return FileName::fromFilesystemEncoding(path).absFilename();
+		return path;
 	}
 
 	// Create a file mapping to get the file name.
@@ -473,7 +541,7 @@ string real_path(string const & path)
 	if (!pmem) {
 		CloseHandle(hmap);
 		CloseHandle(hpath);
-		return FileName::fromFilesystemEncoding(path).absFilename();
+		return path;
 	}
 
 	TCHAR realpath[MAX_PATH + 1];
@@ -482,7 +550,7 @@ string real_path(string const & path)
 		UnmapViewOfFile(pmem);
 		CloseHandle(hmap);
 		CloseHandle(hpath);
-		return FileName::fromFilesystemEncoding(path).absFilename();
+		return path;
 	}
 
 	// Translate device name to UNC prefix or drive letters.
