@@ -114,13 +114,16 @@ extern std::string getParentFilePath();
 
 /*!
  *  Reads tex input from \a infilename and writes lyx output to \a outfilename.
+ *  The (latex) encoding can be provided as \a encoding.
  *  Uses some common settings for the preamble, so this should only
  *  be used more than once for included documents.
  *  Caution: Overwrites the existing preamble settings if the new document
  *  contains a preamble.
  *  \return true if the conversion was successful, else false.
  */
-bool tex2lyx(std::string const & infilename, support::FileName const & outfilename);
+bool tex2lyx(std::string const & infilename, 
+	     support::FileName const & outfilename, 
+	     std::string const & encoding);
 
 
 } // namespace lyx
