@@ -12,12 +12,19 @@
 #ifndef VERSION_H
 #define VERSION_H
 
+//namespace lyx {
+
 ///
 extern char const * lyx_version;
 ///
 extern char const * lyx_release_date;
 
+/// Package identifier (lyx[-<version-suffix>])
+extern char const * lyx_package;
+
 /// This is the version information shown by 'lyx -version'
 extern char const * lyx_version_info;
 
+//} // namespace lyx
+
 #endif
